@@ -19,17 +19,14 @@ from __future__ import print_function
 
 import json
 import os
-import re
 import sys
 
 import jsonschema
-from keystoneclient import exceptions as keystone_exceptions
-from six.moves.urllib import parse
 
 from rally.cli import cliutils
 from rally.cli import envutils
 from rally.common import fileutils
-from rally.common.i18n import _
+from rally.common import logging
 from rally.common import utils
 from rally.common import yamlutils as yaml
 from rally import exceptions
@@ -57,7 +54,8 @@ class DeploymentCommands(object):
         will use the cloud represented in the configuration. If the
         cloud doesn't exist, Rally can deploy a new one for you with
         Devstack or Fuel. Different deployment engines exist for these
-        cases.
+        cases (see `rally plugin list --plugin-base Engine` for
+        more details).
 
         If you use the ExistingCloud deployment engine, you can pass
         the deployment config by environment variables with ``--fromenv``:
@@ -81,35 +79,32 @@ class DeploymentCommands(object):
         cloud. Except physical servers, Rally can create cluster nodes
         for you. Interaction with virtualization software, OpenStack
         cloud or physical servers is provided by server providers.
-
-        :param fromenv: boolean, read environment instead of config file
-        :param filename: path to the configuration file
-        :param name: name of the deployment
         """
 
         if fromenv:
-            config = {"type": "ExistingCloud"}
-            config.update(envutils.get_creds_from_env_vars())
+            # TODO(astudenov): move this to Credential plugin
+            config = {
+                "type": "ExistingCloud",
+                "creds": {"openstack": envutils.get_creds_from_env_vars()}}
         else:
             if not filename:
-                print("Either --filename or --fromenv is required.")
-                return(1)
-            filename = os.path.expanduser(filename)
-            with open(filename, "rb") as deploy_file:
-                config = yaml.safe_load(deploy_file.read())
+                config = {}
+            else:
+                with open(os.path.expanduser(filename), "rb") as deploy_file:
+                    config = yaml.safe_load(deploy_file.read())
 
         try:
-            deployment = api.deployment.create(config, name)
+            deployment = api.deployment.create(config=config, name=name)
         except jsonschema.ValidationError:
-            print(_("Config schema validation error: %s.") % sys.exc_info()[1])
-            return(1)
+            print("Config schema validation error: %s." % sys.exc_info()[1])
+            return 1
         except exceptions.DeploymentNameExists:
-            print(_("Error: %s") % sys.exc_info()[1])
-            return(1)
+            print("Error: %s" % sys.exc_info()[1])
+            return 1
 
         self.list(api, deployment_list=[deployment])
         if do_use:
-            self.use(api, deployment["uuid"])
+            self.use(api, deployment)
 
     @cliutils.args("--filename", type=str, required=False, metavar="<path>",
                    help="Path to the configuration file of the deployment.")
@@ -123,15 +118,13 @@ class DeploymentCommands(object):
 
         Unlike 'deployment destroy', the deployment database record
         will not be deleted, so the deployment UUID stays the same.
-
-        :param deployment: UUID or name of the deployment
         """
         config = None
         if filename:
             with open(filename, "rb") as deploy_file:
                 config = yaml.safe_load(deploy_file.read())
 
-        api.deployment.recreate(deployment, config)
+        api.deployment.recreate(deployment=deployment, config=config)
 
     @cliutils.args("--deployment", dest="deployment", type=str,
                    metavar="<uuid>", required=False,
@@ -145,10 +138,8 @@ class DeploymentCommands(object):
         instances or Fuel clusters created during Rally deployment
         creation. Also it will remove the deployment record from the
         Rally database.
-
-        :param deployment: UUID or name of the deployment
         """
-        api.deployment.destroy(deployment)
+        api.deployment.destroy(deployment=deployment)
 
     def list(self, api, deployment_list=None):
         """List existing deployments."""
@@ -166,9 +157,8 @@ class DeploymentCommands(object):
             cliutils.print_list(table_rows, headers,
                                 sortby_index=headers.index("created_at"))
         else:
-            print(_("There are no deployments. "
-                    "To create a new deployment, use:"
-                    "\nrally deployment create"))
+            print("There are no deployments. To create a new deployment, use:"
+                  "\nrally deployment create")
 
     @cliutils.args("--deployment", dest="deployment", type=str,
                    metavar="<uuid>", required=False,
@@ -180,10 +170,8 @@ class DeploymentCommands(object):
 
         Output is the configuration of the deployment in a
         pretty-printed JSON format.
-
-        :param deployment: UUID or name of the deployment
         """
-        deploy = api.deployment.get(deployment)
+        deploy = api.deployment.get(deployment=deployment)
         result = deploy["config"]
         print(json.dumps(result, sort_keys=True, indent=4))
 
@@ -191,22 +179,21 @@ class DeploymentCommands(object):
                    metavar="<uuid>", required=False,
                    help="UUID or name of the deployment.")
     @envutils.with_default_deployment()
+    @plugins.ensure_plugins_are_loaded
     def show(self, api, deployment=None):
-        """Show the credentials of the deployment.
-
-        :param deployment: UUID or name of the deployment
-        """
+        """Show the credentials of the deployment."""
+        # TODO(astudenov): make this method platform independent
 
         headers = ["auth_url", "username", "password", "tenant_name",
                    "region_name", "endpoint_type"]
         table_rows = []
 
-        deployment = api.deployment.get(deployment)
-        creds = deployment.get_credentials_for("openstack")
+        deployment = api.deployment.get(deployment=deployment)
+
+        creds = deployment["credentials"]["openstack"][0]
         users = creds["users"]
         admin = creds["admin"]
         credentials = users + [admin] if admin else users
-
         for ep in credentials:
             data = ["***" if m == "password" else ep.get(m, "")
                     for m in headers]
@@ -217,48 +204,63 @@ class DeploymentCommands(object):
                    metavar="<uuid>", required=False,
                    help="UUID or name of the deployment.")
     @envutils.with_default_deployment()
+    @plugins.ensure_plugins_are_loaded
     def check(self, api, deployment=None):
-        """Check keystone authentication and list all available services.
+        """Check all credentials and list all available services."""
 
-        :param deployment: UUID or name of the deployment
-        """
-        headers = ["services", "type", "status"]
-        table_rows = []
-        try:
-            deployment = api.deployment.get(deployment)
+        def is_field_there(lst, field):
+            return bool([item for item in lst if field in item])
 
-        except exceptions.DeploymentNotFound:
-            print(_("Deployment %s is not found.") % deployment)
-            return(1)
+        def print_error(user_type, error):
+            print("Error while checking %s credentials:" % user_type)
+            if logging.is_debug():
+                print(error["trace"])
+            else:
+                print("\t%s: %s" % (error["etype"], error["msg"]))
 
-        try:
-            services = api.deployment.check(deployment)
-        except keystone_exceptions.ConnectionRefused:
-            admin = deployment.get_credentials_for("openstack")["admin"]
-            print(_("Unable to connect %s.") % admin["auth_url"])
-            return(1)
+        exit_code = 0
 
-        except exceptions.InvalidArgumentsException:
-            data = ["keystone", "identity", "Error"]
-            table_rows.append(utils.Struct(**dict(zip(headers, data))))
-            print(_("Authentication Issues: %s.")
-                  % sys.exc_info()[1])
-            return(1)
+        info = api.deployment.check(deployment=deployment)
+        for platform in info:
+            for i, credentials in enumerate(info[platform]):
+                failed = False
 
-        for serv_type, serv in services.items():
-            data = [serv, serv_type, "Available"]
-            table_rows.append(utils.Struct(**dict(zip(headers, data))))
-        print(_("keystone endpoints are valid and following"
-              " services are available:"))
-        cliutils.print_list(table_rows, headers)
-        if "__unknown__" in services.values():
-            print(_(
-                "NOTE: '__unknown__' service name means that Keystone service "
-                "catalog doesn't return name for this service and Rally can "
-                "not identify service by its type. BUT you still can use "
-                "such services with api_versions context, specifying type of "
-                "service (execute `rally plugin show api_versions` for more "
-                "details)."))
+                n = "" if len(info[platform]) == 1 else " #%s" % (i + 1)
+                header = "Platform %s%s:" % (platform, n)
+                print(cliutils.make_header(header))
+                if "admin_error" in credentials:
+                    print_error("admin", credentials["admin_error"])
+                    failed = True
+                if "user_error" in credentials:
+                    print_error("users", credentials["user_error"])
+                    failed = True
+
+                if not failed:
+                    print("Available services:")
+                    formatters = {
+                        "Service": lambda x: x.get("name"),
+                        "Service Type": lambda x: x.get("type"),
+                        "Status": lambda x: x.get("status", "Available")}
+                    if (is_field_there(credentials["services"], "type") and
+                            is_field_there(credentials["services"], "name")):
+                        headers = ["Service", "Service Type", "Status"]
+                    else:
+                        headers = ["Service", "Status"]
+
+                    if is_field_there(credentials["services"], "version"):
+                        headers.append("Version")
+
+                    if is_field_there(credentials["services"], "description"):
+                        headers.append("Description")
+
+                    cliutils.print_list(credentials["services"], headers,
+                                        normalize_field_names=True,
+                                        formatters=formatters)
+                else:
+                    exit_code = 1
+                print("\n")
+
+        return exit_code
 
     def _update_openrc_deployment_file(self, deployment, credential):
         openrc_path = os.path.expanduser("~/.rally/openrc-%s" % deployment)
@@ -267,6 +269,7 @@ class DeploymentCommands(object):
                            "export OS_USERNAME='%(username)s'\n"
                            "export OS_PASSWORD='%(password)s'\n"
                            "export OS_TENANT_NAME='%(tenant_name)s'\n"
+                           "export OS_PROJECT_NAME='%(tenant_name)s'\n"
                            % credential)
             if credential.get("region_name"):
                 env_file.write("export OS_REGION_NAME='%s'\n" %
@@ -282,9 +285,9 @@ class DeploymentCommands(object):
             if credential.get("https_cacert"):
                 env_file.write("export OS_CACERT='%s'\n" %
                                credential["https_cacert"])
-            if re.match(r"^/v3/?$", parse.urlparse(
-                    credential["auth_url"]).path) is not None:
-                env_file.write("export OS_USER_DOMAIN_NAME='%s'\n"
+            if credential.get("project_domain_name"):
+                env_file.write("export OS_IDENTITY_API_VERSION=3\n"
+                               "export OS_USER_DOMAIN_NAME='%s'\n"
                                "export OS_PROJECT_DOMAIN_NAME='%s'\n" %
                                (credential["user_domain_name"],
                                 credential["project_domain_name"]))
@@ -296,19 +299,23 @@ class DeploymentCommands(object):
     @cliutils.args("--deployment", dest="deployment", type=str,
                    metavar="<uuid>", required=False,
                    help="UUID or name of a deployment.")
+    @plugins.ensure_plugins_are_loaded
     def use(self, api, deployment):
-        """Set active deployment.
-
-        :param deployment: UUID or name of the deployment
-        """
+        """Set active deployment."""
+        # TODO(astudenov): make this method platform independent
         try:
-            deployment = api.deployment.get(deployment)
-            print("Using deployment: %s" % deployment["uuid"])
+            if not isinstance(deployment, dict):
+                deployment = api.deployment.get(deployment=deployment)
+        except exceptions.DeploymentNotFound:
+            print("Deployment %s is not found." % deployment)
+            return 1
+        print("Using deployment: %s" % deployment["uuid"])
 
-            fileutils.update_globals_file("RALLY_DEPLOYMENT",
-                                          deployment["uuid"])
+        fileutils.update_globals_file("RALLY_DEPLOYMENT",
+                                      deployment["uuid"])
 
-            creds = deployment.get_credentials_for("openstack")
+        if "openstack" in deployment["credentials"]:
+            creds = deployment["credentials"]["openstack"][0]
             self._update_openrc_deployment_file(
                 deployment["uuid"], creds["admin"] or creds["users"][0])
             print("~/.rally/openrc was updated\n\nHINTS:\n"
@@ -316,6 +323,3 @@ class DeploymentCommands(object):
                   "running:\n\tsource ~/.rally/openrc\n"
                   "  OpenStack clients are now configured, e.g run:\n\t"
                   "openstack image list")
-        except exceptions.DeploymentNotFound:
-            print("Deployment %s is not found." % deployment)
-            return 1
