@@ -18,11 +18,9 @@ import abc
 import jsonschema
 import six
 
-from rally.common.i18n import _, _LE
 from rally.common import logging
 from rally.common.plugin import plugin
 from rally import consts
-from rally.deployment.serverprovider import provider
 from rally import exceptions
 
 
@@ -30,10 +28,6 @@ LOG = logging.getLogger(__name__)
 configure = plugin.configure
 
 
-# FIXME(boris-42): We should make decomposition of this class.
-#                  it should be called DeploymentManager
-#                  and it should just manages server providers and engines
-#                  engines class should have own base.
 @plugin.base()
 @six.add_metaclass(abc.ABCMeta)
 class Engine(plugin.Plugin):
@@ -82,12 +76,6 @@ class Engine(plugin.Plugin):
         if hasattr(self, "CONFIG_SCHEMA"):
             jsonschema.validate(config or self.config, self.CONFIG_SCHEMA)
 
-    # FIXME(boris-42): Get rid of this method
-    def get_provider(self):
-        if "provider" in self.config:
-            return provider.ProviderFactory.get_provider(
-                self.config["provider"], self.deployment)
-
     # FIXME(boris-42): Get rid of this method
     @staticmethod
     def get_engine(name, deployment):
@@ -95,13 +83,12 @@ class Engine(plugin.Plugin):
         try:
             engine_cls = Engine.get(name)
             return engine_cls(deployment)
-        except exceptions.PluginNotFound as e:
-            LOG.error(_LE("Deployment %(uuid)s: Deploy engine for %(name)s "
-                      "does not exist.") %
-                      {"uuid": deployment["uuid"], "name": name})
+        except exceptions.PluginNotFound:
+            LOG.error(
+                "Deployment %(uuid)s: Plugin %(name)s doesn't exist."
+                % {"uuid": deployment["uuid"], "name": name})
             deployment.update_status(consts.DeployStatus.DEPLOY_FAILED)
-            raise exceptions.PluginNotFound(
-                namespace=e.kwargs.get("namespace"), name=name)
+            raise
 
     @abc.abstractmethod
     def deploy(self):
@@ -111,21 +98,18 @@ class Engine(plugin.Plugin):
     def cleanup(self):
         """Cleanup OpenStack deployment."""
 
-    @logging.log_deploy_wrapper(LOG.info, _("OpenStack cloud deployment."))
+    @logging.log_deploy_wrapper(LOG.info, "OpenStack cloud deployment.")
     def make_deploy(self):
         self.deployment.set_started()
         credentials = self.deploy()
         self.deployment.set_completed()
         return credentials
 
-    @logging.log_deploy_wrapper(LOG.info, _("Destroy cloud and free "
-                                "allocated resources."))
+    @logging.log_deploy_wrapper(LOG.info,
+                                "Destroy cloud and free allocated resources.")
     def make_cleanup(self):
         self.deployment.update_status(consts.DeployStatus.CLEANUP_STARTED)
         self.cleanup()
-        provider = self.get_provider()
-        if provider:
-            provider.destroy_servers()
         self.deployment.update_status(consts.DeployStatus.CLEANUP_FINISHED)
 
     def __enter__(self):
@@ -136,9 +120,8 @@ class Engine(plugin.Plugin):
             exc_info = None
             if not issubclass(exc_type, exceptions.InvalidArgumentsException):
                 exc_info = (exc_type, exc_value, exc_traceback)
-            LOG.error(_LE("Deployment %(uuid)s: Error has occurred into "
-                      "context of the deployment"),
-                      {"uuid": self.deployment["uuid"]},
+            LOG.error("Deployment %s: Error has occurred in context "
+                      "of the deployment" % self.deployment["uuid"],
                       exc_info=exc_info)
             status = self.deployment["status"]
             if status in (consts.DeployStatus.DEPLOY_INIT,
