@@ -23,16 +23,11 @@ from rally.common import logging
 from rally import consts
 from rally.plugins.openstack.cleanup import base
 from rally.plugins.openstack.services.identity import identity
-from rally.plugins.openstack.wrappers import glance as glance_wrapper
+from rally.plugins.openstack.services.image import glance_v2
+from rally.plugins.openstack.services.image import image
 from rally.task import utils as task_utils
 
 CONF = cfg.CONF
-CONF.import_opt("glance_image_delete_timeout",
-                "rally.plugins.openstack.scenarios.glance.utils",
-                "benchmark")
-CONF.import_opt("glance_image_delete_poll_interval",
-                "rally.plugins.openstack.scenarios.glance.utils",
-                "benchmark")
 
 LOG = logging.getLogger(__name__)
 
@@ -167,38 +162,11 @@ class NovaServerGroups(base.ResourceManager):
     pass
 
 
-@base.resource("nova", "floating_ips", order=next(_nova_order))
-class NovaFloatingIPs(SynchronizedDeletion, base.ResourceManager):
-
-    def list(self):
-        # dirty workaround for openstack gates
-        try:
-            return super(NovaFloatingIPs, self).list()
-        except AttributeError:
-            return []
-
-    def name(self):
-        return self.raw_resource.pool
-
-
 @base.resource("nova", "keypairs", order=next(_nova_order))
 class NovaKeypair(SynchronizedDeletion, base.ResourceManager):
     pass
 
 
-@base.resource("nova", "security_groups", order=next(_nova_order),
-               tenant_resource=True)
-class NovaSecurityGroup(SynchronizedDeletion, base.ResourceManager):
-
-    def list(self):
-        # dirty workaround for openstack gates
-        try:
-            return filter(lambda x: x.name != "default",
-                          super(NovaSecurityGroup, self).list())
-        except AttributeError:
-            return []
-
-
 @base.resource("nova", "quotas", order=next(_nova_order),
                admin_required=True, tenant_resource=True)
 class NovaQuotas(QuotaMixin):
@@ -219,39 +187,6 @@ class NovaFlavors(base.ResourceManager):
         return False
 
 
-@base.resource("nova", "floating_ips_bulk", order=next(_nova_order),
-               admin_required=True)
-class NovaFloatingIpsBulk(SynchronizedDeletion, base.ResourceManager):
-
-    def id(self):
-        return self.raw_resource.address
-
-    def name(self):
-        return None
-
-    def list(self):
-        # dirty workaround for openstack gates
-        try:
-            return super(NovaFloatingIpsBulk, self).list()
-        except AttributeError:
-            return []
-
-
-@base.resource("nova", "networks", order=next(_nova_order),
-               admin_required=True, tenant_resource=True)
-class NovaNetworks(SynchronizedDeletion, base.ResourceManager):
-
-    def name(self):
-        return self.raw_resource.label
-
-    def list(self):
-        # dirty workaround for openstack gates
-        try:
-            return super(NovaNetworks, self).list()
-        except AttributeError:
-            return []
-
-
 @base.resource("nova", "aggregates", order=next(_nova_order),
                admin_required=True, perform_for_admin_only=True)
 class NovaAggregate(SynchronizedDeletion, base.ResourceManager):
@@ -330,11 +265,16 @@ class NeutronMixin(SynchronizedDeletion, base.ResourceManager):
         delete_method(self.id())
 
     def list(self):
-        resources = self._resource + "s"
+        if self._resource.endswith("y"):
+            resources = self._resource[:-1] + "ies"
+        else:
+            resources = self._resource + "s"
         list_method = getattr(self._manager(), "list_%s" % resources)
+        result = list_method(tenant_id=self.tenant_uuid)[resources]
+        if self.tenant_uuid:
+            result = [r for r in result if r["tenant_id"] == self.tenant_uuid]
 
-        return filter(lambda r: r["tenant_id"] == self.tenant_uuid,
-                      list_method(tenant_id=self.tenant_uuid)[resources])
+        return result
 
 
 class NeutronLbaasV1Mixin(NeutronMixin):
@@ -384,6 +324,15 @@ class NeutronV2Loadbalancer(NeutronLbaasV2Mixin):
         return False
 
 
+@base.resource("neutron", "bgpvpn", order=next(_neutron_order),
+               admin_required=True, perform_for_admin_only=True)
+class NeutronBgpvpn(NeutronMixin):
+    def list(self):
+        if self.supports_extension("bgpvpn"):
+            return self._manager().list_bgpvpns()["bgpvpns"]
+        return []
+
+
 # NOTE(andreykurilin): There are scenarios which uses unified way for creating
 #   and associating floating ips. They do not care about nova-net and neutron.
 #   We should clean floating IPs for them, but hardcoding "neutron.floatingip"
@@ -490,8 +439,7 @@ class NeutronPort(NeutronMixin):
             except neutron_exceptions.PortNotFoundClient:
                 # Port can be already auto-deleted, skip silently
                 LOG.debug("Port %s was not deleted. Skip silently because "
-                          "port can be already auto-deleted."
-                          % self.id())
+                          "port can be already auto-deleted." % self.id())
 
 
 @base.resource("neutron", "subnet", order=next(_neutron_order),
@@ -566,12 +514,41 @@ class CinderVolume(base.ResourceManager):
     pass
 
 
+@base.resource("cinder", "image_volumes_cache", order=next(_cinder_order),
+               admin_required=True, perform_for_admin_only=True)
+class CinderImageVolumeCache(base.ResourceManager):
+
+    def _glance(self):
+        return image.Image(self.admin)
+
+    def _manager(self):
+        return self.admin.cinder().volumes
+
+    def list(self):
+        images = dict(("image-%s" % i.id, i)
+                      for i in self._glance().list_images())
+        return [{"volume": v, "image": images[v.name]}
+                for v in self._manager().list(search_opts={"all_tenants": 1})
+                if v.name in images]
+
+    def name(self):
+        return self.raw_resource["image"].name
+
+    def id(self):
+        return self.raw_resource["volume"].id
+
+
 @base.resource("cinder", "quotas", order=next(_cinder_order),
                admin_required=True, tenant_resource=True)
 class CinderQuotas(QuotaMixin, base.ResourceManager):
     pass
 
 
+@base.resource("cinder", "qos_specs", order=next(_cinder_order),
+               admin_required=True, perform_for_admin_only=True)
+class CinderQos(base.ResourceManager):
+    pass
+
 # MANILA
 
 _manila_order = get_order(450)
@@ -601,23 +578,26 @@ class ManilaSecurityService(base.ResourceManager):
 class GlanceImage(base.ResourceManager):
 
     def _client(self):
-        return getattr(self.admin or self.user, self._service)
-
-    def _wrapper(self):
-        return glance_wrapper.wrap(self._client(), self)
+        return image.Image(self.admin or self.user)
 
     def list(self):
-        return self._wrapper().list_images(owner=self.tenant_uuid)
+        images = (self._client().list_images(owner=self.tenant_uuid) +
+                  self._client().list_images(status="deactivated",
+                                             owner=self.tenant_uuid))
+        return images
 
     def delete(self):
         client = self._client()
-        client().images.delete(self.raw_resource.id)
+        if self.raw_resource.status == "deactivated":
+            glancev2 = glance_v2.GlanceV2Service(self.admin or self.user)
+            glancev2.reactivate_image(self.raw_resource.id)
+        client.delete_image(self.raw_resource.id)
         task_utils.wait_for_status(
             self.raw_resource, ["deleted"],
             check_deletion=True,
-            update_resource=self._wrapper().get_image,
-            timeout=CONF.benchmark.glance_image_delete_timeout,
-            check_interval=CONF.benchmark.glance_image_delete_poll_interval)
+            update_resource=self._client().get_image,
+            timeout=CONF.openstack.glance_image_delete_timeout,
+            check_interval=CONF.openstack.glance_image_delete_poll_interval)
 
 
 # SAHARA
@@ -711,76 +691,69 @@ class ZaqarQueues(SynchronizedDeletion, base.ResourceManager):
 
 
 # DESIGNATE
-
 _designate_order = get_order(900)
 
 
 class DesignateResource(SynchronizedDeletion, base.ResourceManager):
-    def _manager(self):
+
+    # TODO(boris-42): This should be handled somewhere else.
+    NAME_PREFIX = "s_rally_"
+
+    def _manager(self, resource=None):
         # Map resource names to api / client version
-        resource_versions = {
+        resource = resource or self._resource
+        version = {
             "domains": "1",
             "servers": "1",
-            "recordsets": 2,
+            "records": "1",
+            "recordsets": "2",
             "zones": "2"
-        }
-        version = resource_versions[self._resource]
-        return getattr(getattr(self.user, self._service)(version),
-                       self._resource)
+        }[resource]
 
-    def _walk_pages(self, func, *args, **kwargs):
-        """Generator that keeps fetching pages until there's none left."""
-        marker = None
+        client = self._admin_required and self.admin or self.user
+        return getattr(getattr(client, self._service)(version), resource)
 
-        while True:
-            items = func(marker=marker, limit=100, *args, **kwargs)
-            if not items:
-                break
-            for item in items:
-                yield item
-            marker = items[-1]["id"]
+    def id(self):
+        """Returns id of resource."""
+        return self.raw_resource["id"]
+
+    def name(self):
+        """Returns name of resource."""
+        return self.raw_resource["name"]
+
+    def list(self):
+        return [item for item in self._manager().list()
+                if item["name"].startswith(self.NAME_PREFIX)]
 
 
-@base.resource("designate", "domains", order=next(_designate_order))
+@base.resource("designate", "domains", order=next(_designate_order),
+               tenant_resource=True, threads=1)
 class DesignateDomain(DesignateResource):
     pass
 
 
 @base.resource("designate", "servers", order=next(_designate_order),
-               admin_required=True, perform_for_admin_only=True)
+               admin_required=True, perform_for_admin_only=True, threads=1)
 class DesignateServer(DesignateResource):
     pass
 
 
-@base.resource("designate", "recordsets", order=next(_designate_order),
-               tenant_resource=True)
-class DesignateRecordSets(DesignateResource):
-    def _client(self):
-        # Map resource names to api / client version
-        resource_versions = {
-            "domains": "1",
-            "servers": "1",
-            "recordsets": 2,
-            "zones": "2"
-        }
-        version = resource_versions[self._resource]
-        return getattr(self.user, self._service)(version)
-
-    def list(self):
-        criterion = {"name": "s_rally_*"}
-        for zone in self._walk_pages(self._client().zones.list,
-                                     criterion=criterion):
-            for recordset in self._walk_pages(self._client().recordsets.list,
-                                              zone["id"]):
-                yield recordset
-
-
 @base.resource("designate", "zones", order=next(_designate_order),
-               tenant_resource=True)
+               tenant_resource=True, threads=1)
 class DesignateZones(DesignateResource):
+
     def list(self):
-        criterion = {"name": "s_rally_*"}
-        return self._walk_pages(self._manager().list, criterion=criterion)
+        marker = None
+        criterion = {"name": "%s*" % self.NAME_PREFIX}
+
+        while True:
+            items = self._manager().list(marker=marker, limit=100,
+                                         criterion=criterion)
+            if not items:
+                break
+            for item in items:
+                yield item
+            marker = items[-1]["id"]
 
 
 # SWIFT
@@ -898,26 +871,6 @@ class IronicNodes(base.ResourceManager):
         return self.raw_resource.uuid
 
 
-# FUEL
-
-@base.resource("fuel", "environment", order=1400,
-               admin_required=True, perform_for_admin_only=True)
-class FuelEnvironment(base.ResourceManager):
-    """Fuel environment.
-
-    That is the only resource that can be deleted by fuelclient explicitly.
-    """
-
-    def id(self):
-        return self.raw_resource["id"]
-
-    def name(self):
-        return self.raw_resource["name"]
-
-    def is_deleted(self):
-        return not self._manager().get(self.id())
-
-
 # WATCHER
 
 _watcher_order = get_order(1500)
@@ -951,7 +904,7 @@ class WatcherTemplate(WatcherMixin):
 class WatcherActionPlan(WatcherMixin):
 
     def name(self):
-        return self.raw_resource.uuid
+        return base.NoName(self._resource)
 
 
 @base.resource("watcher", "audit", order=next(_watcher_order),
