@@ -15,18 +15,15 @@
 
 import pkgutil
 
-from rally.common.i18n import _
-from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import validation
 from rally import consts
 from rally import exceptions
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.scenarios.heat import utils as heat_utils
 from rally.task import context
 
-LOG = logging.getLogger(__name__)
-
 
 def get_data(filename_or_resource):
     if isinstance(filename_or_resource, list):
@@ -34,7 +31,8 @@ def get_data(filename_or_resource):
     return open(filename_or_resource).read()
 
 
-@context.configure(name="heat_dataplane", order=435)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="heat_dataplane", platform="openstack", order=435)
 class HeatDataplane(context.Context):
     """Context class for create stack by given template.
 
@@ -111,7 +109,6 @@ class HeatDataplane(context.Context):
         networks = nc.list_networks(**{"router:external": True})["networks"]
         return networks[0]["id"]
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `HeatDataplane`"))
     def setup(self):
         template = get_data(self.config["template"])
         files = {}
@@ -134,7 +131,8 @@ class HeatDataplane(context.Context):
                 if "key_name" not in parameters:
                     parameters["key_name"] = user["keypair"]["name"]
                 heat_scenario = heat_utils.HeatScenario(
-                    {"user": user, "task": self.context["task"]})
+                    {"user": user, "task": self.context["task"],
+                     "owner_id": self.context["owner_id"]})
                 self.context["tenants"][tenant_id]["stack_dataplane"] = []
                 for i in range(self.config["stacks_per_tenant"]):
                     stack = heat_scenario._create_stack(template, files=files,
@@ -143,7 +141,8 @@ class HeatDataplane(context.Context):
                     tenant_data["stack_dataplane"].append([stack.id, template,
                                                            files, parameters])
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `HeatDataplane`"))
     def cleanup(self):
         resource_manager.cleanup(names=["heat.stacks"],
-                                 users=self.context.get("users", []))
+                                 users=self.context.get("users", []),
+                                 superclass=heat_utils.HeatScenario,
+                                 task_id=self.get_owner_id())
