@@ -12,12 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from rally.common.i18n import _
 from rally.common import logging
 from rally.common import utils as rutils
 from rally import consts
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.scenarios.ec2 import utils as ec2_utils
 from rally.plugins.openstack import types
 from rally.task import context
@@ -26,12 +25,9 @@ from rally.task import context
 LOG = logging.getLogger(__name__)
 
 
-@context.configure(name="ec2_servers", order=460)
+@context.configure(name="ec2_servers", platform="openstack", order=460)
 class EC2ServerGenerator(context.Context):
-    """Context class for adding temporary servers for benchmarks.
-
-    Servers are added for each tenant.
-    """
+    """Creates specified amount of nova servers in each tenant uses ec2 API."""
 
     CONFIG_SCHEMA = {
         "type": "object",
@@ -62,7 +58,6 @@ class EC2ServerGenerator(context.Context):
         "additionalProperties": False
     }
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `EC2 Servers`"))
     def setup(self):
         image = self.config["image"]
         flavor = self.config["flavor"]
@@ -73,17 +68,19 @@ class EC2ServerGenerator(context.Context):
 
         for user, tenant_id in rutils.iterate_per_tenants(
                 self.context["users"]):
-            LOG.debug("Booting servers for tenant %s "
-                      % (user["tenant_id"]))
-            user_clients = osclients.Clients(user["credential"])
-            ec2_scenario = ec2_utils.EC2Scenario(clients=user_clients)
+            LOG.debug("Booting servers for tenant %s " % user["tenant_id"])
+            ec2_scenario = ec2_utils.EC2Scenario({
+                "user": user,
+                "task": self.context["task"],
+                "owner_id": self.context["owner_id"]})
 
             LOG.debug(
                 "Calling _boot_servers with "
-                "image_id={image_id} flavor_name={flavor_name} "
-                "servers_per_tenant={servers_per_tenant}".format(
-                    image_id=image_id, flavor_name=flavor["name"],
-                    servers_per_tenant=self.config["servers_per_tenant"]))
+                "image_id=%(image_id)s flavor_name=%(flavor_name)s "
+                "servers_per_tenant=%(servers_per_tenant)s"
+                % {"image_id": image_id,
+                   "flavor_name": flavor["name"],
+                   "servers_per_tenant": self.config["servers_per_tenant"]})
 
             servers = ec2_scenario._boot_servers(
                 image_id, flavor["name"], self.config["servers_per_tenant"])
@@ -92,9 +89,8 @@ class EC2ServerGenerator(context.Context):
 
             self.context["tenants"][tenant_id]["ec2_servers"] = current_servers
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `EC2 Servers`"))
     def cleanup(self):
         resource_manager.cleanup(names=["ec2.servers"],
                                  users=self.context.get("users", []),
                                  superclass=ec2_utils.EC2Scenario,
-                                 task_id=self.context["task"]["uuid"])
+                                 task_id=self.get_owner_id())
