@@ -15,29 +15,28 @@
 
 from oslo_config import cfg
 
+from rally.common import logging
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.wrappers import glance as glance_wrapper
 from rally.task import atomic
 from rally.task import utils
 
-GLANCE_BENCHMARK_OPTS = [
-    cfg.FloatOpt("glance_image_delete_timeout",
-                 default=120.0,
-                 help="Time to wait for glance image to be deleted."),
-    cfg.FloatOpt("glance_image_delete_poll_interval",
-                 default=1.0,
-                 help="Interval between checks when waiting for image "
-                      "deletion.")
-]
 
 CONF = cfg.CONF
-benchmark_group = cfg.OptGroup(name="benchmark", title="benchmark options")
-CONF.register_opts(GLANCE_BENCHMARK_OPTS, group=benchmark_group)
+LOG = logging.getLogger(__name__)
 
 
 class GlanceScenario(scenario.OpenStackScenario):
     """Base class for Glance scenarios with basic atomic actions."""
 
+    def __init__(self, context=None, admin_clients=None, clients=None):
+        super(GlanceScenario, self).__init__(context, admin_clients, clients)
+        LOG.warning(
+            "Class %s is deprecated since Rally 0.10.0 and will be removed "
+            "soon. Use "
+            "rally.plugins.openstack.services.image.image.Image "
+            "instead." % self.__class__)
+
     @atomic.action_timer("glance.list_images")
     def _list_images(self):
         """Returns user images list."""
@@ -77,5 +76,5 @@ class GlanceScenario(scenario.OpenStackScenario):
             image, ["deleted", "pending_delete"],
             check_deletion=True,
             update_resource=wrapper.get_image,
-            timeout=CONF.benchmark.glance_image_delete_timeout,
-            check_interval=CONF.benchmark.glance_image_delete_poll_interval)
+            timeout=CONF.openstack.glance_image_delete_timeout,
+            check_interval=CONF.openstack.glance_image_delete_poll_interval)
