@@ -17,21 +17,22 @@
 import os
 
 from rally import consts
+from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.murano import utils
-from rally.task import scenario
+from rally.task import types
 from rally.task import validation
 
 
 """Scenarios for Murano packages."""
 
 
-@validation.required_parameters("package")
-@validation.file_exists(param_name="package", mode=os.F_OK)
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["murano.packages"]},
-                    name="MuranoPackages.import_and_list_packages")
+@types.convert(package={"type": "expand_user_path"})
+@validation.add("file_exists", param_name="package", mode=os.F_OK)
+@validation.add("required_services", services=[consts.Service.MURANO])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["murano.packages"]},
+                    name="MuranoPackages.import_and_list_packages",
+                    platform="openstack")
 class ImportAndListPackages(utils.MuranoScenario):
 
     def run(self, package, include_disabled=False):
@@ -57,13 +58,13 @@ class ImportAndListPackages(utils.MuranoScenario):
             os.remove(package_path)
 
 
-@validation.required_parameters("package")
-@validation.file_exists(param_name="package", mode=os.F_OK)
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["murano.packages"]},
-                    name="MuranoPackages.import_and_delete_package")
+@types.convert(package={"type": "expand_user_path"})
+@validation.add("file_exists", param_name="package", mode=os.F_OK)
+@validation.add("required_services", services=[consts.Service.MURANO])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["murano.packages"]},
+                    name="MuranoPackages.import_and_delete_package",
+                    platform="openstack")
 class ImportAndDeletePackage(utils.MuranoScenario):
 
     def run(self, package):
@@ -86,13 +87,13 @@ class ImportAndDeletePackage(utils.MuranoScenario):
             os.remove(package_path)
 
 
-@validation.required_parameters("package", "body")
-@validation.file_exists(param_name="package", mode=os.F_OK)
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["murano.packages"]},
-                    name="MuranoPackages.package_lifecycle")
+@types.convert(package={"type": "expand_user_path"})
+@validation.add("file_exists", param_name="package", mode=os.F_OK)
+@validation.add("required_services", services=[consts.Service.MURANO])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["murano.packages"]},
+                    name="MuranoPackages.package_lifecycle",
+                    platform="openstack")
 class PackageLifecycle(utils.MuranoScenario):
 
     def run(self, package, body, operation="replace"):
@@ -124,13 +125,13 @@ class PackageLifecycle(utils.MuranoScenario):
             os.remove(package_path)
 
 
-@validation.required_parameters("package", "filter_query")
-@validation.file_exists(param_name="package", mode=os.F_OK)
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["murano.packages"]},
-                    name="MuranoPackages.import_and_filter_applications")
+@types.convert(package={"type": "expand_user_path"})
+@validation.add("file_exists", param_name="package", mode=os.F_OK)
+@validation.add("required_services", services=[consts.Service.MURANO])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["murano.packages"]},
+                    name="MuranoPackages.import_and_filter_applications",
+                    platform="openstack")
 class ImportAndFilterApplications(utils.MuranoScenario):
 
     def run(self, package, filter_query):
