@@ -28,20 +28,9 @@ from rally.plugins.openstack import scenario
 from rally.task import atomic
 from rally.task import utils
 
+
 CONF = cfg.CONF
 
-MURANO_BENCHMARK_OPTS = [
-    cfg.IntOpt("murano_deploy_environment_timeout", default=1200,
-               deprecated_name="deploy_environment_timeout",
-               help="A timeout in seconds for an environment deploy"),
-    cfg.IntOpt("murano_deploy_environment_check_interval", default=5,
-               deprecated_name="deploy_environment_check_interval",
-               help="Deploy environment check interval in seconds"),
-]
-
-benchmark_group = cfg.OptGroup(name="benchmark", title="benchmark options")
-CONF.register_opts(MURANO_BENCHMARK_OPTS, group=benchmark_group)
-
 
 class MuranoScenario(scenario.OpenStackScenario):
     """Base class for Murano scenarios with basic atomic actions."""
@@ -81,7 +70,7 @@ class MuranoScenario(scenario.OpenStackScenario):
         """
         return self.clients("murano").sessions.configure(environment_id)
 
-    @atomic.optional_action_timer("murano.create_service")
+    @atomic.action_timer("murano.create_service")
     def _create_service(self, environment, session, full_package_name,
                         image_name=None, flavor_name=None):
         """Create Murano service.
@@ -91,9 +80,6 @@ class MuranoScenario(scenario.OpenStackScenario):
         :param full_package_name: full name of the Murano package
         :param image_name: Image name
         :param flavor_name: Flavor name
-        :param atomic_action: True if this is atomic action. added and
-                              handled by the optional_action_timer()
-                              decorator
         :returns: Service instance
         """
         app_id = str(uuid.uuid4())
@@ -115,8 +101,8 @@ class MuranoScenario(scenario.OpenStackScenario):
         self.clients("murano").sessions.deploy(environment.id,
                                                session.id)
 
-        config = CONF.benchmark
-        utils.wait_for(
+        config = CONF.openstack
+        utils.wait_for_status(
             environment,
             ready_statuses=["READY"],
             update_resource=utils.get_from_manager(["DEPLOY FAILURE"]),
@@ -264,7 +250,7 @@ class MuranoPackageManager(common_utils.RandomNameGeneratorMixin):
             tmp_dir = tempfile.mkdtemp()
             pkg_dir = os.path.join(tmp_dir, "package/")
             try:
-                shutil.copytree(package_path, pkg_dir)
+                shutil.copytree(os.path.expanduser(package_path), pkg_dir)
 
                 self._change_app_fullname(pkg_dir)
                 package_path = fileutils.pack_dir(pkg_dir)
