@@ -23,10 +23,11 @@ from rally.task import validation
 
 @types.convert(strategy={"type": "watcher_strategy"},
                goal={"type": "watcher_goal"})
-@validation.required_services(consts.Service.WATCHER)
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["watcher"]},
-                    name="Watcher.create_audit_template_and_delete")
+@validation.add("required_services", services=[consts.Service.WATCHER])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["watcher"]},
+                    name="Watcher.create_audit_template_and_delete",
+                    platform="openstack")
 class CreateAuditTemplateAndDelete(utils.WatcherScenario):
 
     @logging.log_deprecated_args("Extra field has been removed "
@@ -44,8 +45,8 @@ class CreateAuditTemplateAndDelete(utils.WatcherScenario):
         self._delete_audit_template(audit_template.uuid)
 
 
-@validation.required_services(consts.Service.WATCHER)
-@scenario.configure(name="Watcher.list_audit_templates")
+@validation.add("required_services", services=[consts.Service.WATCHER])
+@scenario.configure(name="Watcher.list_audit_templates", platform="openstack")
 class ListAuditTemplates(utils.WatcherScenario):
 
     def run(self, name=None, goal=None, strategy=None,
@@ -78,10 +79,11 @@ class ListAuditTemplates(utils.WatcherScenario):
                                    sort_dir=sort_dir, detail=detail)
 
 
-@validation.required_services(consts.Service.WATCHER)
-@validation.required_contexts("audit_templates")
-@scenario.configure(context={"admin_cleanup": ["watcher"]},
-                    name="Watcher.create_audit_and_delete")
+@validation.add("required_services", services=[consts.Service.WATCHER])
+@validation.add("required_contexts", contexts="audit_templates")
+@scenario.configure(context={"admin_cleanup@openstack": ["watcher"]},
+                    name="Watcher.create_audit_and_delete",
+                    platform="openstack")
 class CreateAuditAndDelete(utils.WatcherScenario):
 
     def run(self):
