@@ -15,18 +15,30 @@
 
 import abc
 
-import jsonschema
+from oslo_config import cfg
 import six
 
 from rally.common import logging
 from rally.common.plugin import plugin
 from rally.common import utils
+from rally.common import validation
 from rally.task import functional
 
+
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
+CONF_OPTS = [
+    cfg.StrOpt(
+        "context_resource_name_format",
+        help="Template is used to generate random names of resources. X is"
+             "replaced with random latter, amount of X can be adjusted")
+]
+CONF.register_opts(CONF_OPTS)
 
 
-def configure(name, order, namespace="default", hidden=False):
+@logging.log_deprecated_args("Use 'platform' arg instead", "0.10.0",
+                             ["namespace"], log_function=LOG.warning)
+def configure(name, order, platform="default", namespace=None, hidden=False):
     """Context class wrapper.
 
     Each context class has to be wrapped by configure() wrapper. It
@@ -34,14 +46,18 @@ def configure(name, order, namespace="default", hidden=False):
     adds attributes to the class.
 
     :param name: Name of the class, used in the input task
+    :param platform: str plugin's platform
     :param order: As far as we can use multiple context classes that sometimes
                   depend on each other we have to specify order of execution.
                   Contexts with smaller order are run first
     :param hidden: If it is true you won't be able to specify context via
                    task config
     """
+    if namespace:
+        platform = namespace
+
     def wrapper(cls):
-        cls = plugin.configure(name=name, namespace=namespace,
+        cls = plugin.configure(name=name, platform=platform,
                                hidden=hidden)(cls)
         cls._meta_set("order", order)
         return cls
@@ -49,7 +65,24 @@ def configure(name, order, namespace="default", hidden=False):
     return wrapper
 
 
-# TODO(andreykurilin): move it to some common place.
+def add_default_context(name, config):
+    """Add default context that is inherit by all children plugins.
+
+    :param name: str, name of the validator plugin
+    :param kwargs: dict, arguments used to initialize validator class
+        instance
+    """
+
+    def wrapper(plugin):
+        plugin._default_meta_setdefault("default_context", {})
+        plugin._default_meta_get("default_context")[name] = config
+        return plugin
+
+    return wrapper
+
+
+# TODO(andreykurilin): BaseContext is used by Task and Verification and should
+#                      be moved to common place
 @six.add_metaclass(abc.ABCMeta)
 class BaseContext(plugin.Plugin, functional.FunctionalMixin,
                   utils.RandomNameGeneratorMixin):
@@ -70,7 +103,14 @@ class BaseContext(plugin.Plugin, functional.FunctionalMixin,
     CONFIG_SCHEMA = {"type": "null"}
 
     def __init__(self, ctx):
-        config = ctx.get("config", {}).get(self.get_name(), {})
+        config = ctx.get("config", {})
+        if self.get_name() in config:
+            # TODO(boris-42): Fix tests, code is always using fullnames
+            config = config[self.get_name()]
+        else:
+            # TODO(boris-42): use [] instead of get() context full name is
+            #                 always presented.
+            config = config.get(self.get_fullname(), {})
         # NOTE(amaretskiy): self.config is a constant data and must be
         #                   immutable or write-protected type to prevent
         #                   unexpected changes in runtime
@@ -88,22 +128,6 @@ class BaseContext(plugin.Plugin, functional.FunctionalMixin,
             self.config = config
         self.context = ctx
 
-    def __lt__(self, other):
-        return self.get_order() < other.get_order()
-
-    def __gt__(self, other):
-        return self.get_order() > other.get_order()
-
-    def __eq__(self, other):
-        return self.get_order() == other.get_order()
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    @classmethod
-    def validate(cls, config):
-        jsonschema.validate(config, cls.CONFIG_SCHEMA)
-
     @classmethod
     def get_order(cls):
         return cls._meta_get("order")
@@ -140,12 +164,23 @@ class BaseContext(plugin.Plugin, functional.FunctionalMixin,
         self.cleanup()
 
 
+@validation.add_default("jsonschema")
 @plugin.base()
-class Context(BaseContext):
+class Context(BaseContext, validation.ValidatablePluginMixin):
     def __init__(self, ctx):
         super(Context, self).__init__(ctx)
         self.task = self.context.get("task", {})
 
+    @classmethod
+    def _get_resource_name_format(cls):
+        return (CONF.context_resource_name_format
+                or super(Context, cls)._get_resource_name_format())
+
+    def get_owner_id(self):
+        if "owner_id" in self.context:
+            return self.context["owner_id"]
+        return super(Context, self).get_owner_id()
+
 
 class ContextManager(object):
     """Create context environment and run method inside it."""
@@ -154,36 +189,51 @@ class ContextManager(object):
         self._visited = []
         self.context_obj = context_obj
 
-    @staticmethod
-    def validate(ctx, allow_hidden=False):
-        for name, config in ctx.items():
-            Context.get(name, allow_hidden=allow_hidden).validate(config)
-
     def _get_sorted_context_lst(self):
-        return sorted([
-            Context.get(ctx_name, allow_hidden=True)(self.context_obj)
-            for ctx_name in self.context_obj["config"].keys()])
+        ctx_lst = [Context.get(name, allow_hidden=True)
+                   for name in self.context_obj["config"]]
+        ctx_lst.sort(key=lambda x: x.get_order())
+        return [c(self.context_obj) for c in ctx_lst]
+
+    def _log_prefix(self):
+        return "Task %s |" % self.context_obj["task"]["uuid"]
 
     def setup(self):
-        """Creates benchmark environment from config."""
-
+        """Creates environment by executing provided context plugins."""
         self._visited = []
         for ctx in self._get_sorted_context_lst():
             self._visited.append(ctx)
-            ctx.setup()
+            msg = ("%(log_prefix)s Context %(name)s setup() "
+                   % {"log_prefix": self._log_prefix(),
+                      "name": ctx.get_fullname()})
+
+            with utils.Timer() as timer:
+                LOG.info("%s started" % msg)
+                ctx.setup()
+
+            LOG.info("%(msg)s finished in %(duration)s"
+                     % {"msg": msg, "duration": timer.duration(fmt=True)})
 
         return self.context_obj
 
     def cleanup(self):
-        """Destroys benchmark environment."""
-
+        """Cleans up  environment by executing provided context plugins."""
         ctxlst = self._visited or self._get_sorted_context_lst()
         for ctx in ctxlst[::-1]:
+            msg = ("%(log_prefix)s Context %(name)s cleanup()"
+                   % {"log_prefix": self._log_prefix(),
+                      "name": ctx.get_fullname()})
+            timer = utils.Timer()
             try:
-                ctx.cleanup()
-            except Exception as e:
-                LOG.error("Context %s failed during cleanup." % ctx.get_name())
-                LOG.exception(e)
+                with timer:
+                    LOG.info("%s started" % msg)
+                    ctx.cleanup()
+                LOG.info("%(msg)s finished in %(duration)s"
+                         % {"msg": msg, "duration": timer.duration(fmt=True)})
+            except Exception:
+                LOG.exception(
+                    "%(msg)s failed after %(duration)s"
+                    % {"msg": msg, "duration": timer.duration(fmt=True)})
 
     def __enter__(self):
         try:
