@@ -16,6 +16,7 @@
 import collections
 import datetime as dt
 import hashlib
+import itertools
 import json
 
 import six
@@ -23,7 +24,9 @@ import six
 from rally.common import objects
 from rally.common.plugin import plugin
 from rally.common import version
+from rally import exceptions
 from rally.task.processing import charts
+from rally.task import scenario
 from rally.ui import utils as ui_utils
 
 
@@ -31,7 +34,7 @@ def _process_hooks(hooks):
     """Prepare hooks data for report."""
     hooks_ctx = []
     for hook in hooks:
-        hook_ctx = {"name": hook["config"]["name"],
+        hook_ctx = {"name": hook["config"]["action"][0],
                     "desc": hook["config"].get("description", ""),
                     "additive": [], "complete": []}
 
@@ -40,7 +43,8 @@ def _process_hooks(hooks):
             finished_at = dt.datetime.utcfromtimestamp(res["finished_at"])
             triggered_by = "%(event_type)s: %(value)s" % res["triggered_by"]
 
-            for i, data in enumerate(res.get("output", {}).get("additive")):
+            for i, data in enumerate(
+                    res.get("output", {}).get("additive", [])):
                 try:
                     hook_ctx["additive"][i]
                 except IndexError:
@@ -49,7 +53,7 @@ def _process_hooks(hooks):
                 hook_ctx["additive"][i].append(data)
 
             complete_charts = []
-            for data in res.get("output", {}).get("complete"):
+            for data in res.get("output", {}).get("complete", []):
                 chart_cls = plugin.Plugin.get(data.pop("chart_plugin"))
                 data["widget"] = chart_cls.widget
                 complete_charts.append(data)
@@ -68,7 +72,7 @@ def _process_hooks(hooks):
             first = hook_ctx["additive"][i][0]
             descr = first.get("description", "")
             axis_label = first.get("axis_label", "")
-            chart = chart_cls({"iterations_count": iters_count},
+            chart = chart_cls({"total_iteration_count": iters_count},
                               title=first["title"],
                               description=descr,
                               label=first.get("label", ""),
@@ -82,20 +86,20 @@ def _process_hooks(hooks):
     return hooks_ctx
 
 
-def _process_scenario(data, pos):
-    main_area = charts.MainStackedAreaChart(data["info"])
-    main_hist = charts.MainHistogramChart(data["info"])
-    main_stat = charts.MainStatsTable(data["info"])
-    load_profile = charts.LoadProfileChart(data["info"])
-    atomic_pie = charts.AtomicAvgChart(data["info"])
-    atomic_area = charts.AtomicStackedAreaChart(data["info"])
-    atomic_hist = charts.AtomicHistogramChart(data["info"])
+def _process_workload(workload, workload_cfg, pos):
+    main_area = charts.MainStackedAreaChart(workload)
+    main_hist = charts.MainHistogramChart(workload)
+    main_stat = charts.MainStatsTable(workload)
+    load_profile = charts.LoadProfileChart(workload)
+    atomic_pie = charts.AtomicAvgChart(workload)
+    atomic_area = charts.AtomicStackedAreaChart(workload)
+    atomic_hist = charts.AtomicHistogramChart(workload)
 
     errors = []
     output_errors = []
     additive_output_charts = []
     complete_output = []
-    for idx, itr in enumerate(data["iterations"], 1):
+    for idx, itr in enumerate(workload["data"], 1):
         if itr["error"]:
             typ, msg, trace = itr["error"]
             errors.append({"iteration": idx,
@@ -107,7 +111,7 @@ def _process_scenario(data, pos):
             except IndexError:
                 chart_cls = plugin.Plugin.get(additive["chart_plugin"])
                 chart = chart_cls(
-                    data["info"], title=additive["title"],
+                    workload, title=additive["title"],
                     description=additive.get("description", ""),
                     label=additive.get("label", ""),
                     axis_label=additive.get("axis_label",
@@ -127,22 +131,21 @@ def _process_scenario(data, pos):
                       atomic_pie, atomic_area, atomic_hist):
             chart.add_iteration(itr)
 
-    kw = data["key"]["kw"]
-    cls, method = data["key"]["name"].split(".")
+    cls, method = workload["name"].split(".")
     additive_output = [chart.render() for chart in additive_output_charts]
-    iterations_count = data["info"]["iterations_count"]
 
     return {
         "cls": cls,
         "met": method,
         "pos": str(pos),
         "name": method + (pos and " [%d]" % (pos + 1) or ""),
-        "runner": kw["runner"]["type"],
-        "config": json.dumps({data["key"]["name"]: [kw]}, indent=2),
-        "hooks": _process_hooks(data["hooks"]),
+        "runner": workload["runner_type"],
+        "config": json.dumps(workload_cfg, indent=2),
+        "hooks": _process_hooks(workload["hooks"]),
+        "description": workload.get("description", ""),
         "iterations": {
             "iter": main_area.render(),
-            "pie": [("success", (data["info"]["iterations_count"]
+            "pie": [("success", (workload["total_iteration_count"]
                                  - len(errors))),
                     ("errors", len(errors))],
             "histogram": main_hist.render()},
@@ -156,72 +159,95 @@ def _process_scenario(data, pos):
         "has_output": any(additive_output) or any(complete_output),
         "output_errors": output_errors,
         "errors": errors,
-        "load_duration": data["info"]["load_duration"],
-        "full_duration": data["info"]["full_duration"],
-        "created_at": data["created_at"],
-        "sla": data["sla"],
-        "sla_success": all([s["success"] for s in data["sla"]]),
-        "iterations_count": iterations_count,
+        "load_duration": workload["load_duration"],
+        "full_duration": workload["full_duration"],
+        "created_at": workload["created_at"],
+        "sla": workload["sla_results"].get("sla"),
+        "sla_success": workload["pass_sla"],
+        "iterations_count": workload["total_iteration_count"],
     }
 
 
-def _process_tasks(tasks_results):
-    tasks = []
-    source_dict = collections.defaultdict(list)
+def _process_workloads(workloads):
+    p_workloads = []
     position = collections.defaultdict(lambda: -1)
 
-    for scenario in tasks_results:
-        name = scenario["key"]["name"]
+    for workload in workloads:
+        name = workload["name"]
         position[name] += 1
-        source_dict[name].append(scenario["key"]["kw"])
-        tasks.append(_process_scenario(scenario, position[name]))
+        workload_cfg = objects.Workload.to_task(workload)
+        p_workloads.append(_process_workload(workload, workload_cfg,
+                                             position[name]))
 
-    source = json.dumps(source_dict, indent=2, sort_keys=True)
-    return source, sorted(tasks, key=lambda r: (r["cls"], r["met"],
-                                                int(r["pos"])))
+    return sorted(p_workloads,
+                  key=lambda r: (r["cls"], r["met"], int(r["pos"])))
 
 
-def _extend_results(results):
-    """Transform tasks results into extended format.
-
-    This is a temporary workaround adapter that allows
-    working with task results using new schema, until
-    database refactoring actually comes.
-
-    :param results: tasks results list in old format
-    :returns: tasks results list in new format
-    """
-    extended_results = []
-    for result in results:
-        generic = {"id": None,
-                   "task_uuid": None,
-                   "key": result["key"],
-                   "data": {"sla": result["sla"],
-                            "hooks": result.get("hooks"),
-                            "raw": result["result"],
-                            "full_duration": result["full_duration"],
-                            "load_duration": result["load_duration"]},
-                   "created_at": result.get("created_at"),
-                   "updated_at": None}
-        extended_results.extend(
-            objects.Task.extend_results([generic], True))
-    return extended_results
+def _make_source(tasks):
+    # TODO(andreykurilin): include tags someday
+    source = collections.OrderedDict([("version", 2)])
+    single_task = (len(tasks) == 1)
+    if not single_task:
+        source["title"] = "A combined task."
+        source["description"] = ("The task contains subtasks from a multiple "
+                                 "number of tasks.")
+    else:
+        source["title"] = tasks[0]["title"]
+        source["description"] = tasks[0]["description"]
+    source["subtasks"] = []
+    for task in tasks:
+        for subtask in task["subtasks"]:
+            subtask_cfg = collections.OrderedDict()
+            subtask_cfg["title"] = subtask["title"]
+            subtask_cfg["description"] = subtask["description"]
+            if not single_task:
+                # save original identifiers.
+                if subtask_cfg["description"]:
+                    subtask_cfg["description"] += "\n"
+                subtask_cfg["description"] += (
+                    "[Task UUID: %s]" % task["uuid"])
+            # subtask_cfg["tags"] = subtask["tags"]
+            subtask_cfg["workloads"] = []
+            for workload in subtask["workloads"]:
+                workload_cfg = collections.OrderedDict()
+                workload_cfg["scenario"] = {workload["name"]: workload["args"]}
+                workload_cfg["description"] = workload["description"]
+                workload_cfg["contexts"] = workload["context"]
+                workload_cfg["runner"] = {
+                    workload["runner_type"]: workload["runner"]}
+                workload_cfg["hooks"] = [h["config"]
+                                         for h in workload["hooks"]]
+                workload_cfg["sla"] = workload["sla"]
+                subtask_cfg["workloads"].append(workload_cfg)
+            source["subtasks"].append(subtask_cfg)
+    return json.dumps(source, indent=2)
 
 
 def plot(tasks_results, include_libs=False):
-    extended_results = _extend_results(tasks_results)
+    source = _make_source(tasks_results)
+    tasks = []
+    subtasks = []
+    workloads = []
+    for task in tasks_results:
+        tasks.append(task)
+        for subtask in tasks[-1]["subtasks"]:
+            workloads.extend(subtask.pop("workloads"))
+        subtasks.extend(tasks[-1].pop("subtasks"))
+
     template = ui_utils.get_template("task/report.html")
-    source, data = _process_tasks(extended_results)
+    data = _process_workloads(workloads)
     return template.render(version=version.version_string(),
                            source=json.dumps(source),
                            data=json.dumps(data),
                            include_libs=include_libs)
 
 
-def trends(tasks_results):
+def trends(tasks):
     trends = Trends()
-    for i, scenario in enumerate(_extend_results(tasks_results), 1):
-        trends.add_result(scenario)
+    for task in tasks:
+        for workload in itertools.chain(
+                *[s["workloads"] for s in task["subtasks"]]):
+            trends.add_result(task["uuid"], workload)
     template = ui_utils.get_template("task/trends.html")
     return template.render(version=version.version_string(),
                            data=json.dumps(trends.get_data()))
@@ -256,61 +282,84 @@ class Trends(object):
     def _make_hash(self, obj):
         return hashlib.md5(self._to_str(obj).encode("utf8")).hexdigest()
 
-    def add_result(self, result):
-        key = self._make_hash(result["key"]["kw"])
+    def add_result(self, task_uuid, workload):
+        workload_cfg = objects.Workload.to_task(workload)
+        # NOTE(andreykurilin): workload_cfg is a complite task with one only
+        #   one workload. Task format v2 includes such fields like task
+        #   description (it contains UUID of an original task), workload
+        #   description. These fields do not affect the workload itself, but
+        #   makes workload_cfg too unique. We need to crop these fields to find
+        #   workloads with equal configs.
+        del workload_cfg["description"]
+        w_description = workload_cfg["subtasks"][0].pop("description")
+        key = self._make_hash(workload_cfg)
         if key not in self._data:
             self._data[key] = {
                 "actions": {},
                 "sla_failures": 0,
-                "name": result["key"]["name"],
-                "config": json.dumps(result["key"]["kw"], indent=2)}
+                "name": workload["name"],
+                "tasks": [],
+                "description": w_description,
+                "config": workload_cfg}
 
-        for sla in result["sla"]:
-            self._data[key]["sla_failures"] += not sla["success"]
+        self._data[key]["tasks"].append(task_uuid)
+        if (self._data[key]["description"] and
+                self._data[key]["description"] != w_description):
+            self._data[key]["description"] = None
 
-        stat = {row[0]: dict(zip(result["info"]["stat"]["cols"], row))
-                for row in result["info"]["stat"]["rows"]}
-        ts = int(result["info"]["tstamp_start"] * 1000)
+        self._data[key]["sla_failures"] += not workload["pass_sla"]
 
-        for action in stat:
+        duration_stats = workload["statistics"]["durations"]
+        ts = int(workload["start_time"] * 1000)
+
+        for action in itertools.chain(duration_stats["atomics"],
+                                      [duration_stats["total"]]):
+            action_name = action["display_name"]
             # NOTE(amaretskiy): some atomic actions can be missed due to
             #   failures. We can ignore that because we use NVD3 lineChart()
             #   for displaying trends, which is safe for missed points
-            if action not in self._data[key]["actions"]:
-                self._data[key]["actions"][action] = {
+            if action_name not in self._data[key]["actions"]:
+                self._data[key]["actions"][action_name] = {
                     "durations": {"min": [], "median": [], "90%ile": [],
                                   "95%ile": [], "max": [], "avg": []},
                     "success": []}
-
             try:
-                success = float(stat[action]["Success"].rstrip("%"))
+                success = float(action["data"]["success"].rstrip("%"))
             except ValueError:
                 # Got "n/a" for some reason
                 success = 0
 
-            self._data[key]["actions"][action]["success"].append(
+            self._data[key]["actions"][action_name]["success"].append(
                 (ts, success))
 
-            for tgt, src in (("min", "Min (sec)"),
-                             ("median", "Median (sec)"),
-                             ("90%ile", "90%ile (sec)"),
-                             ("95%ile", "95%ile (sec)"),
-                             ("max", "Max (sec)"),
-                             ("avg", "Avg (sec)")):
-
-                self._data[key]["actions"][action]["durations"][tgt].append(
-                    (ts, stat[action][src]))
+            for tgt in ("min", "median", "90%ile", "95%ile", "max", "avg"):
+                d = self._data[key]["actions"][action_name]["durations"]
+                d[tgt].append((ts, action["data"][tgt]))
 
     def get_data(self):
         trends = []
 
         for wload in self._data.values():
+            workload_cfg = wload["config"]
+            # TODO(andreykurilin): The description can be too long and
+            #   unfriendly while displaying. Move displaying tasks UUIDs
+            #   under html report control.
+            workload_cfg["description"] = ("Task(s) with the workload: %s" %
+                                           ", ".join(wload["tasks"]))
+            if not wload["description"]:
+                try:
+                    wload["description"] = scenario.Scenario.get(
+                        wload["name"]).get_info()["title"]
+                except (exceptions.PluginNotFound,
+                        exceptions.MultiplePluginsFound):
+                    wload["description"] = ""
+            workload_cfg["subtasks"][0]["description"] = wload["description"]
             trend = {"stat": {},
                      "name": wload["name"],
                      "cls": wload["name"].split(".")[0],
                      "met": wload["name"].split(".")[1],
                      "sla_failures": wload["sla_failures"],
-                     "config": wload["config"],
+                     "config": json.dumps(workload_cfg, indent=2),
                      "actions": []}
 
             for action, data in wload["actions"].items():
