@@ -22,7 +22,7 @@ import six
 
 from rally.common.plugin import plugin
 from rally import exceptions
-from rally import osclients
+from rally.plugins.openstack import osclients
 from rally.task import scenario
 
 
@@ -79,9 +79,8 @@ def preprocess(name, context, args):
     """Run preprocessor on scenario arguments.
 
     :param name: Plugin name
-    :param context: dictionary object that must have admin and credential
-                    entries
-    :param args: args section of benchmark specification in rally task file
+    :param context: dict with contexts data
+    :param args: args section of input task file
 
     :returns processed_args: dictionary object with additional client
                              and resource configuration
@@ -89,7 +88,13 @@ def preprocess(name, context, args):
     """
     preprocessors = scenario.Scenario.get(name)._meta_get("preprocessors",
                                                           default={})
-    clients = osclients.Clients(context["admin"]["credential"])
+
+    clients = None
+    if context.get("admin"):
+        clients = osclients.Clients(context["admin"]["credential"])
+    elif context.get("users"):
+        clients = osclients.Clients(context["users"][0]["credential"])
+
     processed_args = copy.deepcopy(args)
 
     for src, preprocessor in preprocessors.items():
@@ -115,6 +120,10 @@ class ResourceType(plugin.Plugin):
         :returns: transformed value of resource
         """
 
+    @classmethod
+    def _get_doc(cls):
+        return cls.transform.__doc__
+
 
 def obj_from_name(resource_config, resources, typename):
     """Return the resource whose name matches the pattern.
@@ -189,11 +198,6 @@ def obj_from_id(resource_config, resources, typename):
                     if resource.id == resource_config["id"]]
         if len(matching) == 1:
             return matching[0]
-        elif len(matching) > 1:
-            raise exceptions.MultipleMatchesFound(
-                needle="{typename} with id '{id}'".format(
-                    typename=typename.title(), id=resource_config["id"]),
-                haystack=matching)
         else:
             raise exceptions.InvalidScenarioArgument(
                 "{typename} with id '{id}' not found".format(
