@@ -20,8 +20,10 @@ import threading
 import time
 import unittest
 
+import jsonschema
 import mock
 
+from rally import api
 from tests.functional import utils
 
 
@@ -54,48 +56,31 @@ class TaskTestCase(unittest.TestCase):
                     "group": "Dummy group",
                     "description": "The first subtask in dummy task",
                     "tags": ["dummy", "functional_test"],
-                    "run_in_parallel": False,
-                    "workloads": [{
-                        "name": "Dummy.dummy",
-                        "args": {
-                            "sleep": 0
-                        },
-                        "runner": {
-                            "type": "constant",
-                            "times": 10,
-                            "concurrency": 2
-                        },
-                        "context": {
-                            "users": {
-                                "tenants": 3,
-                                "users_per_tenant": 2
+                    "workloads": [
+                        {
+                            "scenario": {
+                                "Dummy.dummy": {"sleep": 0}},
+                            "runner": {
+                                "constant": {
+                                    "times": 10,
+                                    "concurrency": 2
+                                }
                             }
                         }
-                    }]
+                    ]
                 },
                 {
                     "title": "second-subtask",
-                    "group": "Dummy group",
                     "description": "The second subtask in dummy task",
                     "tags": ["dummy", "functional_test"],
-                    "run_in_parallel": False,
-                    "workloads": [{
-                        "name": "Dummy.dummy",
-                        "args": {
-                            "sleep": 1
-                        },
-                        "runner": {
-                            "type": "constant",
+                    "scenario": {
+                        "Dummy.dummy": {"sleep": 1}},
+                    "runner": {
+                        "constant": {
                             "times": 10,
                             "concurrency": 2
-                        },
-                        "context": {
-                            "users": {
-                                "tenants": 3,
-                                "users_per_tenant": 2
-                            }
                         }
-                    }]
+                    }
                 }
             ]
         }
@@ -105,6 +90,11 @@ class TaskTestCase(unittest.TestCase):
             r"Using deployment: (?P<uuid>[0-9a-f\-]{36})",
             output).group("uuid")
 
+    def _get_task_uuid(self, output):
+        return re.search(
+            r"\trally task report (?P<uuid>[0-9a-f\-]{36})",
+            output).group("uuid")
+
     def test_status(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
@@ -119,9 +109,9 @@ class TaskTestCase(unittest.TestCase):
         rally("task start --task %s" % config.filename)
         detailed = rally("task detailed")
         self.assertIn("Dummy.dummy_random_fail_in_atomic", detailed)
-        self.assertIn("dummy_fail_test (2)", detailed)
+        self.assertIn("dummy_fail_test (x2)", detailed)
         detailed_iterations_data = rally("task detailed --iterations-data")
-        self.assertIn(". dummy_fail_test (2)", detailed_iterations_data)
+        self.assertIn(". dummy_fail_test (x2)", detailed_iterations_data)
         self.assertNotIn("n/a", detailed_iterations_data)
 
     def test_detailed_with_errors(self):
@@ -183,6 +173,28 @@ class TaskTestCase(unittest.TestCase):
         self.assertRaises(utils.RallyCliError,
                           rally, "task results --uuid %s" % FAKE_TASK_UUID)
 
+    def test_import_results(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        json_report = rally.gen_report_path(extension="json")
+        with open(json_report, "w+") as f:
+            f.write(rally("task results"))
+        import_print = rally("task import --file %s" % json_report)
+        self.assertIn("successfully", import_print)
+        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        self.assertIn("Dummy.dummy_random_fail_in_atomic",
+                      rally("task results --uuid %s" % task_uuid))
+
+        # new json report
+        rally("task report --json --out %s" % json_report)
+        import_print = rally("task import --file %s" % json_report)
+        self.assertIn("successfully", import_print)
+        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        self.assertIn("Dummy.dummy_random_fail_in_atomic",
+                      rally("task report --uuid %s --json" % task_uuid))
+
     def test_abort_with_wrong_task_id(self):
         rally = utils.Rally()
         self.assertRaises(utils.RallyCliError,
@@ -202,6 +214,8 @@ class TaskTestCase(unittest.TestCase):
         rally = utils.Rally()
         self.assertRaises(utils.RallyCliError,
                           rally, "task report --tasks %s" % FAKE_TASK_UUID)
+        self.assertRaises(utils.RallyCliError,
+                          rally, "task report --uuid %s" % FAKE_TASK_UUID)
 
     def test_sla_check_with_wrong_task_id(self):
         rally = utils.Rally()
@@ -231,16 +245,22 @@ class TaskTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        rally("task report --out %s" % rally.gen_report_path(extension="html"))
         html_report = rally.gen_report_path(extension="html")
+        rally("task report --out %s" % html_report)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report, False)
         self.assertRaises(utils.RallyCliError,
                           rally, "task report --report %s" % FAKE_TASK_UUID)
-        rally("task report --junit --out %s" %
-              rally.gen_report_path(extension="junit"))
-        self.assertTrue(os.path.exists(
-            rally.gen_report_path(extension="junit")))
+
+    def test_new_report_one_uuid(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        html_report = rally.gen_report_path(extension="html")
+        rally("task report --out %s" % html_report)
+        self.assertTrue(os.path.exists(html_report))
+        self._assert_html_report_libs_are_embedded(html_report, False)
         self.assertRaises(utils.RallyCliError,
                           rally, "task report --report %s" % FAKE_TASK_UUID)
 
@@ -251,15 +271,26 @@ class TaskTestCase(unittest.TestCase):
         task_uuids = []
         for i in range(3):
             res = rally("task start --task %s" % config.filename)
-            for line in res.splitlines():
-                if "finished" in line:
-                    task_uuids.append(line.split(" ")[1][:-1])
+            task_uuids.append(self._get_task_uuid(res))
         html_report = rally.gen_report_path(extension="html")
         rally("task report --tasks %s --out %s" % (" ".join(task_uuids),
                                                    html_report))
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report, False)
 
+    def test_new_report_bunch_uuids(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        task_uuids = []
+        for i in range(3):
+            res = rally("task start --task %s" % config.filename)
+            task_uuids.append(self._get_task_uuid(res))
+        html_report = rally.gen_report_path(extension="html")
+        rally("task report --uuid %s --out %s" % (" ".join(task_uuids),
+                                                  html_report))
+        self.assertTrue(os.path.exists(html_report))
+
     def test_report_bunch_files(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
@@ -287,16 +318,13 @@ class TaskTestCase(unittest.TestCase):
         task_result_file = "/tmp/report_42.json"
         if os.path.exists(task_result_file):
             os.remove(task_result_file)
-        rally("task results", report_path=task_result_file, raw=True)
+        rally("task results", report_path=task_result_file,
+              raw=True)
 
         task_run_output = rally(
-            "task start --task %s" % config.filename).splitlines()
-        for line in task_run_output:
-            if "finished" in line:
-                task_uuid = line.split(" ")[1][:-1]
-                break
-        else:
-            return 1
+            "task start --task %s" % config.filename)
+        task_uuid = self._get_task_uuid(task_run_output)
+        task_run_output = task_run_output.splitlines()
 
         html_report = rally.gen_report_path(extension="html")
         rally("task report --tasks"
@@ -307,6 +335,23 @@ class TaskTestCase(unittest.TestCase):
                           rally, "task report --report %s" % FAKE_TASK_UUID)
         self._assert_html_report_libs_are_embedded(html_report, False)
 
+    def test_report_one_file_with_static_libs(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        task_result_file = "/tmp/report_42.json"
+        if os.path.exists(task_result_file):
+            os.remove(task_result_file)
+        rally("task results", report_path=task_result_file,
+              raw=True)
+
+        html_report = rally.gen_report_path(extension="html")
+        rally("task report --html-static %s --out %s"
+              % (task_result_file, html_report))
+        self.assertTrue(os.path.exists(html_report))
+        self._assert_html_report_libs_are_embedded(html_report)
+
     def test_report_one_uuid_with_static_libs(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
@@ -317,21 +362,88 @@ class TaskTestCase(unittest.TestCase):
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report)
 
+    def test_new_report_one_uuid_with_static_libs(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        html_report = rally.gen_report_path(extension="html")
+        rally("task report --out %s --html-static" % html_report)
+        self.assertTrue(os.path.exists(html_report))
+        self._assert_html_report_libs_are_embedded(html_report)
+
+    def _assert_json_report(self, file_path):
+        results = json.loads(open(file_path).read())
+        self.assertIn("info", results)
+        self.assertIn("tasks", results)
+        for task in results["tasks"]:
+            jsonschema.validate(task,
+                                api._Task.TASK_SCHEMA)
+
+    def test_report_one_uuid_with_json(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        json_report = rally.gen_report_path(extension="json")
+        rally("task report --out %s --json" % json_report)
+        self.assertTrue(os.path.exists(json_report))
+        self._assert_json_report(json_report)
+
+    def test_report_bunch_uuids_with_json(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        task_uuids = []
+        for i in range(3):
+            res = rally("task start --task %s" % config.filename)
+            task_uuids.append(self._get_task_uuid(res))
+        json_report = rally.gen_report_path(extension="json")
+        rally("task report --json --uuid %s --out %s"
+              % (" ".join(task_uuids), json_report))
+        self.assertTrue(os.path.exists(json_report))
+        self._assert_json_report(json_report)
+
     def test_trends(self):
         cfg1 = {
             "Dummy.dummy": [
-                {"runner": {"type": "constant", "times": 2,
-                            "concurrency": 2}}],
+                {
+                    "runner": {
+                        "type": "constant",
+                        "times": 2,
+                        "concurrency": 2
+                    }
+                }
+            ],
             "Dummy.dummy_random_action": [
-                {"args": {"actions_num": 4},
-                 "runner": {"type": "constant", "times": 2, "concurrency": 2}},
-                {"runner": {"type": "constant", "times": 2,
-                            "concurrency": 2}}]}
+                {
+                    "args": {"actions_num": 4},
+                    "runner": {
+                        "type": "constant",
+                        "times": 2,
+                        "concurrency": 2
+                    }
+                },
+                {
+                    "runner": {
+                        "type": "constant",
+                        "times": 2,
+                        "concurrency": 2
+                    }
+                }
+            ]
+        }
         cfg2 = {
             "Dummy.dummy": [
-                {"args": {"sleep": 0.6},
-                 "runner": {"type": "constant", "times": 2,
-                            "concurrency": 2}}]}
+                {
+                    "args": {"sleep": 0.2},
+                    "runner": {
+                        "type": "constant", "times": 2,
+                        "concurrency": 2
+                    }
+                }
+            ]
+        }
 
         config1 = utils.TaskConfig(cfg1)
         config2 = utils.TaskConfig(cfg2)
@@ -339,12 +451,13 @@ class TaskTestCase(unittest.TestCase):
         report = rally.gen_report_path(extension="html")
 
         for i in range(5):
-            rally("task start --task %(file)s --tag trends_run_%(idx)d"
-                  % {"file": config1.filename, "idx": i})
-        rally("task start --task %s --tag trends_run_once" % config2.filename)
+            rally("task start --task %(file)s --tag trends_run "
+                  "run_%(idx)d" % {"file": config1.filename, "idx": i})
+        rally("task start --task %s --tag trends_run run_once" %
+              config2.filename)
 
-        tasks_list = rally("task list")
-        uuids = [u[2:38] for u in tasks_list.split("\n") if "trends_run" in u]
+        tasks_list = rally("task list --uuids-only --tag trends_run")
+        uuids = [u for u in tasks_list.split("\n") if u]
 
         rally("task trends %(uuids)s --out %(report)s"
               % {"uuids": " ".join(uuids), "report": report})
@@ -368,9 +481,37 @@ class TaskTestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
+        output = rally("task start --task %s --tag foo" % config.filename)
+        task_uuid = self._get_task_uuid(output)
+        # obtain the task object from the database, to check that CLI prints
+        # everything right
+        rapi = api.API(config_file=rally.config_filename)
+        task = rapi.task.get(task_id=task_uuid)
 
-        self.assertIn("finished", rally("task list --deployment MAIN"))
+        actual = rally("task list --deployment MAIN")
+        duration = "%s" % round(task["task_duration"], 3)
+        duration += " " * (13 - len(duration))
+        expected = (
+            "+--------------------------------------+-----------------+"
+            "---------------------+---------------+----------+--------+\n"
+            "| UUID                                 | Deployment name "
+            "| Created at          | Load duration | Status   | Tag(s) |\n"
+            "+--------------------------------------+-----------------+"
+            "---------------------+---------------+----------+--------+\n"
+            "| %(uuid)s | MAIN            | %(created_at)s "
+            "| %(duration)s | finished | 'foo'  |\n"
+            "+--------------------------------------+-----------------+"
+            "---------------------+---------------+----------+--------+\n" % {
+                "uuid": task_uuid,
+                "created_at": task["created_at"].replace("T", " "),
+                "duration": duration})
+
+        # self.assertEqual is not used here, since it doesn't show a big diff
+        # and error message become useless
+        if expected != actual:
+            self.fail("AssertionError: Expected output is not equal to actual."
+                      "\nExpected:\"\"\"\n%s\n\"\"\""
+                      "\nActual:\"\"\"\n%s\n\"\"\"" % (expected, actual))
 
         self.assertIn("There are no tasks",
                       rally("task list --status crashed"))
@@ -378,7 +519,7 @@ class TaskTestCase(unittest.TestCase):
         self.assertIn("finished", rally("task list --status finished"))
 
         self.assertIn(
-            "deployment_name", rally("task list --all-deployments"))
+            "Deployment name", rally("task list --all-deployments"))
 
         self.assertRaises(utils.RallyCliError,
                           rally, "task list --status not_existing_status")
@@ -392,33 +533,33 @@ class TaskTestCase(unittest.TestCase):
         self.assertEqual("", rally("task list --uuids-only"))
 
         # Validate against a single task
-        res = rally("task start --task %s" % config.filename)
-        task_uuids = []
-        for line in res.splitlines():
-            if "finished" in line:
-                task_uuids.append(line.split(" ")[1][:-1])
-        self.assertGreater(len(task_uuids), 0)
-        self.assertIn(task_uuids[0],
-                      rally("task list --uuids-only --deployment MAIN"))
+        res = rally("task start --task %s --tag " % config.filename)
+        task_uuid = self._get_task_uuid(res)
+        self.assertEqual(
+            task_uuid,
+            rally("task list --uuids-only --deployment MAIN").strip())
+        self.assertIn("finished", rally("task status --uuid %s" % task_uuid))
 
         # Validate against multiple tasks
+        task_uuids = [task_uuid]
         for i in range(2):
-            rally("task start --task %s" % config.filename)
-            self.assertIn("finished", rally("task list --deployment MAIN"))
+            out = rally("task start --task %s" % config.filename)
+            task_uuid = self._get_task_uuid(out)
+            task_uuids.append(task_uuid)
+            self.assertIn("finished",
+                          rally("task status --uuid %s" % task_uuid))
         res = rally("task list --uuids-only --deployment MAIN")
-        task_uuids = res.split()
-        self.assertEqual(3, len(task_uuids))
-        res = rally("task list --uuids-only --deployment MAIN "
-                    "--status finished")
-        for uuid in task_uuids:
-            self.assertIn(uuid, res)
+        self.assertEqual(set(task_uuids), set(res.strip().split("\n")))
+        res2 = rally("task list --uuids-only --deployment MAIN "
+                     "--status finished")
+        self.assertEqual(res, res2)
 
     def test_validate_is_valid(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
         output = rally("task validate --task %s" % config.filename)
-        self.assertIn("Task config is valid", output)
+        self.assertIn("Input Task is valid :)", output)
 
     def test_validate_is_invalid(self):
         rally = utils.Rally()
@@ -455,7 +596,7 @@ class TaskTestCase(unittest.TestCase):
                        {"task_file": task_file,
                         "plugin_paths": plugin_paths})
 
-        self.assertIn("Task config is valid", output)
+        self.assertIn("Input Task is valid :)", output)
 
         plugin_paths = ("tests/functional/extra/fake_dir1/"
                         "fake_plugin1.py,"
@@ -467,7 +608,7 @@ class TaskTestCase(unittest.TestCase):
                        {"task_file": task_file,
                         "plugin_paths": plugin_paths})
 
-        self.assertIn("Task config is valid", output)
+        self.assertIn("Input Task is valid :)", output)
 
         plugin_paths = ("tests/functional/extra/fake_dir1/,"
                         "tests/functional/extra/fake_dir2/"
@@ -478,7 +619,7 @@ class TaskTestCase(unittest.TestCase):
                        {"task_file": task_file,
                         "plugin_paths": plugin_paths})
 
-        self.assertIn("Task config is valid", output)
+        self.assertIn("Input Task is valid :)", output)
 
     def _test_start_abort_on_sla_failure_success(self, cfg, times):
         rally = utils.Rally()
@@ -828,10 +969,7 @@ class TaskTestCase(unittest.TestCase):
         task.join()
         results = json.loads(rally("task results"))
         iterations_completed = len(results[0]["result"])
-        # NOTE(msdubov): check that the task is stopped after first runner
-        #                benchmark finished all its iterations
         self.assertEqual(3, iterations_completed)
-        # NOTE(msdubov): check that the next benchmark scenario is not started
         self.assertEqual(1, len(results))
         self.assertIn("aborted", rally("task status"))
 
@@ -863,58 +1001,36 @@ class TaskTestCase(unittest.TestCase):
             r"(?P<task_id>[0-9a-f\-]{36}): started", output)
         self.assertIsNotNone(result)
 
-    def test_export(self):
+    def test_export_one_uuid(self):
         rally = utils.Rally()
-        cfg = {
-            "Dummy.dummy": [
-                {
-                    "runner": {
-                        "type": "constant",
-                        "times": 100,
-                        "concurrency": 5
-                    }
-                }
-            ]
-        }
+        cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
-        output = rally("task start --task %s" % config.filename)
-        uuid = re.search(
-            r"(?P<uuid>[0-9a-f\-]{36}): started", output).group("uuid")
-        connection = (
-            "file-exporter:///" + rally.gen_report_path(extension="json"))
-        output = rally("task export --uuid %s --connection %s" % (
-            uuid, connection))
-        expected = (
-            "Task %(uuid)s results was successfully exported to %("
-            "connection)s using file-exporter plugin." % {
-                "uuid": uuid,
-                "connection": connection,
-            })
-        self.assertIn(expected, output)
+        rally("task start --task %s" % config.filename)
+        html_report = rally.gen_report_path(extension="html")
+        rally("task export --type html --to %s" % html_report)
+        self.assertTrue(os.path.exists(html_report))
+        self._assert_html_report_libs_are_embedded(html_report, False)
 
-    def test_export_with_wrong_connection(self):
+        rally("task export --type html-static --to %s" % html_report)
+        self.assertTrue(os.path.exists(html_report))
+        self._assert_html_report_libs_are_embedded(html_report)
+
+        junit_report = rally.gen_report_path(extension="junit")
+        rally("task export --type junit-xml --to %s" % junit_report)
+        self.assertTrue(os.path.exists(junit_report))
+
+    def test_export_bunch_uuids(self):
         rally = utils.Rally()
-        cfg = {
-            "Dummy.dummy": [
-                {
-                    "runner": {
-                        "type": "constant",
-                        "times": 100,
-                        "concurrency": 5
-                    }
-                }
-            ]
-        }
+        cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
-        output = rally("task start --task %s" % config.filename)
-        uuid = re.search(
-            r"(?P<uuid>[0-9a-f\-]{36}): started", output).group("uuid")
-        connection = (
-            "fake:///" + rally.gen_report_path(extension="json"))
-        self.assertRaises(utils.RallyCliError,
-                          rally,
-                          "task export --uuid %s --connection %s" % (
-                              uuid, connection))
+        task_uuids = []
+        for i in range(3):
+            res = rally("task start --task %s" % config.filename)
+            task_uuids.append(self._get_task_uuid(res))
+        html_report = rally.gen_report_path(extension="html")
+        rally("task export --uuid %s --type html --to %s" % (
+            " ".join(task_uuids), html_report))
+        self.assertTrue(os.path.exists(html_report))
 
 
 class SLATestCase(unittest.TestCase):
@@ -922,10 +1038,10 @@ class SLATestCase(unittest.TestCase):
     def _get_sample_task_config(self, max_seconds_per_iteration=4,
                                 failure_rate_max=0):
         return {
-            "KeystoneBasic.create_and_list_users": [
+            "Dummy.dummy": [
                 {
                     "args": {
-                        "enabled": True
+                        "sleep": 0.2
                     },
                     "runner": {
                         "type": "constant",
@@ -953,11 +1069,11 @@ class SLATestCase(unittest.TestCase):
         rally("task start --task %s" % config.filename)
         rally("task sla-check")
         expected = [
-            {"benchmark": "KeystoneBasic.create_and_list_users",
+            {"benchmark": "Dummy.dummy",
              "criterion": "failure_rate",
              "detail": mock.ANY,
              "pos": 0, "status": "PASS"},
-            {"benchmark": "KeystoneBasic.create_and_list_users",
+            {"benchmark": "Dummy.dummy",
              "criterion": "max_seconds_per_iteration",
              "detail": mock.ANY,
              "pos": 0, "status": "PASS"}
@@ -999,7 +1115,7 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
         try:
             rally("task sla-check --json", getjson=True)
         except utils.RallyCliError as expected_error:
-            self.assertEqual(json.loads(expected_error.output), expected)
+            self.assertEqual(expected, json.loads(expected_error.output))
         else:
             self.fail("`rally task sla-check` command should return non-zero "
                       "exit code")
@@ -1019,6 +1135,12 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         expected = [
+            {"status": "PASS",
+             "benchmark": "Dummy.dummy",
+             "criterion": "failure_rate",
+             "detail": "Failure rate criteria 0.00% <= 0.00% <= 0.00% - "
+                       "Passed",
+             "pos": 0},
             {"benchmark": "Dummy.dummy",
              "criterion": "something_went_wrong",
              "detail": mock.ANY,
@@ -1027,7 +1149,7 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
         try:
             rally("task sla-check --json", getjson=True)
         except utils.RallyCliError as expected_error:
-            self.assertEqual(json.loads(expected_error.output), expected)
+            self.assertEqual(expected, json.loads(expected_error.output))
         else:
             self.fail("`rally task sla-check` command should return non-zero "
                       "exit code")
@@ -1110,35 +1232,39 @@ class HookTestCase(unittest.TestCase):
 
     def _get_sample_task_config(self, cmd, description, runner):
         return {
-            "Dummy.dummy": [
-                {
-                    "args": {
-                        "sleep": 0.1,
-                    },
-                    "runner": runner,
-                    "hooks": [
-                        {
-                            "name": "sys_call",
-                            "description": description,
-                            "args": cmd,
-                            "trigger": {
-                                "name": "event",
-                                "args": {
-                                    "unit": "iteration",
-                                    "at": [5],
-                                }
-                            }
-                        }
-                    ]
-                }
+            "version": 2,
+            "title": "Testing hooks",
+            "subtasks": [
+                {"title": "Simple workload",
+                 "scenario": {
+                     "Dummy.dummy": {"sleep": 0.1}},
+                 "runner": runner,
+                 "hooks": [
+                     {"description": description,
+                      "action": {"sys_call": cmd},
+                      "trigger": {
+                          "event": {"unit": "iteration",
+                                    "at": [5]}
+                      }
+                      }]
+                 }
             ]
         }
 
     def _get_result(self, config, iterations=None, seconds=None, error=False):
-        result = {"config": config, "results": [], "summary": {}}
+        action_name, action_cfg = list(config["action"].items())[0]
+        trigger_name, trigger_cfg = list(config["trigger"].items())[0]
+        result = {
+            "config": {
+                "description": config.get("description", ""),
+                "name": action_name, "args": action_cfg,
+                "trigger": {"name": trigger_name,
+                            "args": trigger_cfg}},
+            "results": [], "summary": {}}
         events = iterations if iterations else seconds
         event_type = "iteration" if iterations else "time"
         status = "failed" if error else "success"
+        action_args = list(config["action"].values())[0]
         for i in range(len(events)):
             itr_result = {
                 "finished_at": mock.ANY,
@@ -1151,7 +1277,7 @@ class HookTestCase(unittest.TestCase):
                                   "data": ["RetCode: %i" % error,
                                            "StdOut: (empty)",
                                            "StdErr: (empty)"],
-                                  "description": "Args: %s" % config["args"],
+                                  "description": "Args: %s" % action_args,
                                   "title": "System call"}]}}
             if error:
                 itr_result["error"] = {"etype": "n/a",
@@ -1166,12 +1292,12 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/true",
             description="event_hook",
-            runner={"type": "constant", "times": 10, "concurrency": 3})
+            runner={"constant": {"times": 10, "concurrency": 3}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
         self.assertEqual(expected, hook_results)
         self._assert_results_time(hook_results)
@@ -1181,13 +1307,13 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/true",
             description="event_hook",
-            runner={"type": "constant_for_duration",
-                    "concurrency": 3, "duration": 10})
+            runner={"constant_for_duration": {
+                "concurrency": 3, "duration": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
         self.assertEqual(expected, hook_results)
         self._assert_results_time(hook_results)
@@ -1197,12 +1323,12 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/true",
             description="event_hook",
-            runner={"type": "rps", "rps": 3, "times": 10})
+            runner={"rps": {"rps": 3, "times": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
         self.assertEqual(expected, hook_results)
         self._assert_results_time(hook_results)
@@ -1212,12 +1338,12 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/true",
             description="event_hook",
-            runner={"type": "serial", "times": 10})
+            runner={"serial": {"times": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
         self.assertEqual(expected, hook_results)
         self._assert_results_time(hook_results)
@@ -1227,12 +1353,12 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/false",
             description="event_hook",
-            runner={"type": "constant", "times": 20, "concurrency": 3})
+            runner={"constant": {"times": 20, "concurrency": 3}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5], error=True)]
         self.assertEqual(expected, hook_results)
         self._assert_results_time(hook_results)
@@ -1242,15 +1368,13 @@ class HookTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config(
             cmd="/bin/true",
             description="event_hook",
-            runner={"type": "constant_for_duration",
-                    "concurrency": 3, "duration": 10})
-        cfg["Dummy.dummy"][0]["hooks"].append({
-            "name": "sys_call",
+            runner={"constant_for_duration":
+                        {"concurrency": 3, "duration": 10}})
+        cfg["subtasks"][0]["hooks"].append({
             "description": "time_hook",
-            "args": "/bin/true",
+            "action": {"sys_call": "/bin/true"},
             "trigger": {
-                "name": "event",
-                "args": {
+                "event": {
                     "unit": "time",
                     "at": [3, 6, 9],
                 }
@@ -1262,11 +1386,56 @@ class HookTestCase(unittest.TestCase):
         results = json.loads(rally("task results"))
         hook_results = results[0]["hooks"]
 
-        hooks_cfg = cfg["Dummy.dummy"][0]["hooks"]
+        hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5]),
                     self._get_result(hooks_cfg[1], seconds=[3, 6, 9])]
         self.assertEqual(
             expected,
             sorted(hook_results,
-                   key=lambda i: i["config"]["trigger"]["args"]["unit"]))
+                   key=lambda i: list(
+                       i["config"]["trigger"].values())[0]["unit"]))
         self._assert_results_time(hook_results)
+
+    def test_import_hook_result(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(
+            cmd="/bin/true",
+            description="event_hook",
+            runner={"constant": {"times": 10, "concurrency": 3}})
+        cfg["subtasks"][0]["hooks"].extend(
+            [
+                {
+                    "description": "Show time",
+                    "action": {"sys_call": "date +%Y-%m-%dT%H:%M:%S"},
+                    "trigger": {
+                        "event": {
+                            "unit": "time",
+                            "at": [1, 2],
+                        }
+                    }
+                },
+                {
+                    "description": "Show system name",
+                    "action": {"sys_call": "uname -a"},
+                    "trigger": {
+                        "event": {
+                            "unit": "iteration",
+                            "at": [3, 6, 9],
+                        }
+                    }
+                }
+            ]
+        )
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        json_report = rally.gen_report_path(extension="json")
+        with open(json_report, "w+") as f:
+            f.write(rally("task results"))
+        import_print = rally("task import --file %s" % json_report)
+        self.assertIn("successfully", import_print)
+        task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
+        results = rally("task results --uuid %s" % task_uuid)
+        self.assertIn("Dummy.dummy", results)
+        self.assertIn("event_hook", results)
+        self.assertIn("Show time", results)
+        self.assertIn("Show system name", results)
