@@ -16,6 +16,7 @@
 import ddt
 import mock
 
+from rally import exceptions as rally_exceptions
 from rally.plugins.openstack.scenarios.neutron import network
 from tests.unit import test
 
@@ -157,6 +158,51 @@ class NeutronNetworksTestCase(test.ScenarioTestCase):
 
         scenario._list_subnets.assert_called_once_with()
 
+    def test_create_and_show_subnets(self):
+        network_create_args = {"router:external": True}
+        subnet_create_args = {"allocation_pools": []}
+        subnet_cidr_start = "1.1.0.0/30"
+        subnets_per_network = 5
+        net = mock.MagicMock()
+
+        scenario = network.CreateAndShowSubnets(self.context)
+        scenario._get_or_create_network = mock.Mock(return_value=net)
+        scenario._create_subnets = mock.MagicMock()
+        scenario._show_subnet = mock.Mock()
+
+        scenario.run(network_create_args=network_create_args,
+                     subnet_create_args=subnet_create_args,
+                     subnet_cidr_start=subnet_cidr_start,
+                     subnets_per_network=subnets_per_network)
+
+        scenario._get_or_create_network.assert_called_once_with(
+            network_create_args)
+        scenario._create_subnets.assert_called_once_with(
+            net, subnet_create_args, subnet_cidr_start, subnets_per_network)
+        for subnet in scenario._create_subnets.return_value:
+            scenario._show_subnet.assert_called_with(subnet)
+
+    def test_set_and_clear_router_gateway(self):
+        network_create_args = {"router:external": True}
+        router_create_args = {"admin_state_up": True}
+        enable_snat = True
+        ext_net = mock.MagicMock()
+        router = mock.MagicMock()
+        scenario = network.SetAndClearRouterGateway(self.context)
+        scenario._create_network = mock.Mock(return_value=ext_net)
+        scenario._create_router = mock.Mock(return_value=router)
+        scenario._add_gateway_router = mock.Mock()
+        scenario._remove_gateway_router = mock.Mock()
+
+        scenario.run(enable_snat, network_create_args, router_create_args)
+
+        scenario._create_network.assert_called_once_with(
+            network_create_args)
+        scenario._create_router.assert_called_once_with(router_create_args)
+        scenario._add_gateway_router.assert_called_once_with(router, ext_net,
+                                                             enable_snat)
+        scenario._remove_gateway_router.assert_called_once_with(router)
+
     def test_create_and_update_subnets(self):
         network_create_args = {"router:external": True}
         subnet_create_args = {"allocation_pools": []}
@@ -305,6 +351,34 @@ class NeutronNetworksTestCase(test.ScenarioTestCase):
         scenario._delete_router.assert_has_calls(
             [mock.call(router) for router in routers])
 
+    def test_create_and_show_routers(self):
+        network_create_args = {"router:external": True}
+        subnet_create_args = {"allocation_pools": []}
+        subnet_cidr_start = "default_cidr"
+        subnets_per_network = 5
+        router_create_args = {"admin_state_up": True}
+        net = mock.MagicMock()
+        subnets = [mock.MagicMock() for i in range(subnets_per_network)]
+        routers = [mock.MagicMock() for i in range(subnets_per_network)]
+
+        scenario = network.CreateAndShowRouters(self.context)
+        scenario._create_network_structure = mock.Mock(
+            return_value=(net, subnets, routers))
+        scenario._show_router = mock.Mock()
+
+        scenario.run(network_create_args=network_create_args,
+                     subnet_create_args=subnet_create_args,
+                     subnet_cidr_start=subnet_cidr_start,
+                     subnets_per_network=subnets_per_network,
+                     router_create_args=router_create_args)
+
+        scenario._create_network_structure.assert_called_once_with(
+            network_create_args, subnet_create_args, subnet_cidr_start,
+            subnets_per_network, router_create_args)
+
+        scenario._show_router.assert_has_calls(
+            [mock.call(router) for router in routers])
+
     def test_create_and_list_ports(self):
         port_create_args = {"allocation_pools": []}
         ports_per_network = 10
@@ -352,6 +426,69 @@ class NeutronNetworksTestCase(test.ScenarioTestCase):
         scenario._update_port.assert_has_calls(
             [mock.call(p, port_update_args) for p in ports])
 
+    def test_create_and_show_ports_positive(self):
+        port_create_args = {"allocation_pools": []}
+        ports_per_network = 1
+        network_create_args = {"router:external": True}
+        net = mock.MagicMock()
+
+        scenario = network.CreateAndShowPorts(self.context)
+        scenario._get_or_create_network = mock.MagicMock(return_value=net)
+        scenario._create_port = mock.MagicMock()
+        scenario._show_port = mock.MagicMock()
+        port = {"port": {"id": 1, "name": "f"}}
+        port_info = {"port": {"id": 1, "name": "f", "status": "ACTIVE"}}
+        scenario._show_port.return_value = port_info
+
+        # Positive case:
+        scenario._create_port.return_value = port
+        scenario.run(network_create_args=network_create_args,
+                     port_create_args=port_create_args,
+                     ports_per_network=ports_per_network)
+        scenario._get_or_create_network.assert_called_once_with(
+            network_create_args)
+        scenario._create_port.assert_called_with(net, port_create_args)
+        scenario._show_port.assert_called_with(port)
+
+    def test_create_and_show_ports_negative(self):
+        port_create_args = {"allocation_pools": []}
+        ports_per_network = 1
+        network_create_args = {"router:external": True}
+        net = mock.MagicMock()
+
+        scenario = network.CreateAndShowPorts(self.context)
+        scenario._get_or_create_network = mock.MagicMock(return_value=net)
+        scenario._create_port = mock.MagicMock()
+        scenario._show_port = mock.MagicMock()
+
+        # Negative case1: port isn't created
+        scenario._create_port.return_value = None
+        self.assertRaises(rally_exceptions.RallyAssertionError,
+                          scenario.run,
+                          network_create_args,
+                          port_create_args,
+                          ports_per_network)
+        scenario._get_or_create_network.assert_called_once_with(
+            network_create_args)
+        scenario._create_port.assert_called_once_with(net, port_create_args)
+
+        # Negative case2: port isn't show
+        port = {"port": {"id": 1, "name": "f1"}}
+        port_info = {"port": {"id": 2, "name": "f2", "status": "ACTIVE"}}
+        scenario._show_port.return_value = port_info
+        scenario._create_port.return_value = port
+
+        self.assertRaises(rally_exceptions.RallyAssertionError,
+                          scenario.run,
+                          network_create_args,
+                          port_create_args,
+                          ports_per_network)
+
+        scenario._get_or_create_network.assert_called_with(
+            network_create_args)
+        scenario._create_port.assert_called_with(net, port_create_args)
+        scenario._show_port.assert_called_with(port)
+
     def test_create_and_delete_ports(self):
         port_create_args = {"allocation_pools": []}
         ports_per_network = 10
