@@ -37,8 +37,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self.volume = mock.Mock()
         self.floating_ip = mock.Mock()
         self.image = mock.Mock()
-        self.context["iteration"] = 3
-        self.context["config"] = {"users": {"tenants": 2}}
+        self.context.update(
+            {"user": {"id": "fake_user_id", "credential": mock.MagicMock()}})
 
     def _context_with_networks(self, networks):
         retval = {"tenant": {"networks": networks}}
@@ -112,8 +112,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_boot_poll_interval,
-            timeout=CONF.benchmark.nova_server_boot_timeout)
+            check_interval=CONF.openstack.nova_server_boot_poll_interval,
+            timeout=CONF.openstack.nova_server_boot_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self.assertEqual(self.mock_wait_for_status.mock.return_value,
                          return_server)
@@ -155,8 +155,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["SUSPENDED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_suspend_poll_interval,
-            timeout=CONF.benchmark.nova_server_suspend_timeout)
+            check_interval=CONF.openstack.nova_server_suspend_poll_interval,
+            timeout=CONF.openstack.nova_server_suspend_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.suspend_server")
@@ -169,8 +169,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_resume_poll_interval,
-            timeout=CONF.benchmark.nova_server_resume_timeout)
+            check_interval=CONF.openstack.nova_server_resume_poll_interval,
+            timeout=CONF.openstack.nova_server_resume_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.resume_server")
@@ -183,8 +183,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["PAUSED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_pause_poll_interval,
-            timeout=CONF.benchmark.nova_server_pause_timeout)
+            check_interval=CONF.openstack.nova_server_pause_poll_interval,
+            timeout=CONF.openstack.nova_server_pause_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.pause_server")
@@ -197,8 +197,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_unpause_poll_interval,
-            timeout=CONF.benchmark.nova_server_unpause_timeout)
+            check_interval=CONF.openstack.nova_server_unpause_poll_interval,
+            timeout=CONF.openstack.nova_server_unpause_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.unpause_server")
@@ -211,8 +211,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["SHELVED_OFFLOADED"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_shelve_poll_interval,
-            timeout=CONF.benchmark.nova_server_shelve_timeout)
+            check_interval=CONF.openstack.nova_server_shelve_poll_interval,
+            timeout=CONF.openstack.nova_server_shelve_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.shelve_server")
@@ -225,24 +225,25 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_unshelve_poll_interval,
-            timeout=CONF.benchmark.nova_server_unshelve_timeout)
+            check_interval=CONF.openstack.nova_server_unshelve_poll_interval,
+            timeout=CONF.openstack.nova_server_unshelve_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.unshelve_server")
 
-    def test__create_image(self):
-        self.clients("nova").images.get.return_value = self.image
+    @mock.patch("rally.plugins.openstack.scenarios.nova.utils.image_service")
+    def test__create_image(self, mock_image_service):
+        glance = mock_image_service.Image.return_value
+        glance.get_image.return_value = self.image
         nova_scenario = utils.NovaScenario(context=self.context)
         return_image = nova_scenario._create_image(self.server)
         self.mock_wait_for_status.mock.assert_called_once_with(
             self.image,
             ready_statuses=["ACTIVE"],
-            update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.
+            update_resource=glance.get_image,
+            check_interval=CONF.openstack.
             nova_server_image_create_poll_interval,
-            timeout=CONF.benchmark.nova_server_image_create_timeout)
-        self.mock_get_from_manager.mock.assert_called_once_with()
+            timeout=CONF.openstack.nova_server_image_create_timeout)
         self.assertEqual(self.mock_wait_for_status.mock.return_value,
                          return_image)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
@@ -257,8 +258,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             ready_statuses=["deleted"],
             check_deletion=True,
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_delete_poll_interval,
-            timeout=CONF.benchmark.nova_server_delete_timeout)
+            check_interval=CONF.openstack.nova_server_delete_poll_interval,
+            timeout=CONF.openstack.nova_server_delete_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.delete_server")
@@ -272,8 +273,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             ready_statuses=["deleted"],
             check_deletion=True,
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_delete_poll_interval,
-            timeout=CONF.benchmark.nova_server_delete_timeout)
+            check_interval=CONF.openstack.nova_server_delete_poll_interval,
+            timeout=CONF.openstack.nova_server_delete_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.force_delete_server")
@@ -286,8 +287,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_reboot_poll_interval,
-            timeout=CONF.benchmark.nova_server_reboot_timeout)
+            check_interval=CONF.openstack.nova_server_reboot_poll_interval,
+            timeout=CONF.openstack.nova_server_reboot_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.reboot_server")
@@ -300,8 +301,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_reboot_poll_interval,
-            timeout=CONF.benchmark.nova_server_reboot_timeout)
+            check_interval=CONF.openstack.nova_server_reboot_poll_interval,
+            timeout=CONF.openstack.nova_server_reboot_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.soft_reboot_server")
@@ -314,8 +315,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_rebuild_poll_interval,
-            timeout=CONF.benchmark.nova_server_rebuild_timeout)
+            check_interval=CONF.openstack.nova_server_rebuild_poll_interval,
+            timeout=CONF.openstack.nova_server_rebuild_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.rebuild_server")
@@ -328,8 +329,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_start_poll_interval,
-            timeout=CONF.benchmark.nova_server_start_timeout)
+            check_interval=CONF.openstack.nova_server_start_poll_interval,
+            timeout=CONF.openstack.nova_server_start_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.start_server")
@@ -342,8 +343,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["SHUTOFF"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_stop_poll_interval,
-            timeout=CONF.benchmark.nova_server_stop_timeout)
+            check_interval=CONF.openstack.nova_server_stop_poll_interval,
+            timeout=CONF.openstack.nova_server_stop_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.stop_server")
@@ -356,8 +357,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["RESCUE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_rescue_poll_interval,
-            timeout=CONF.benchmark.nova_server_rescue_timeout)
+            check_interval=CONF.openstack.nova_server_rescue_poll_interval,
+            timeout=CONF.openstack.nova_server_rescue_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.rescue_server")
@@ -370,8 +371,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_unrescue_poll_interval,
-            timeout=CONF.benchmark.nova_server_unrescue_timeout)
+            check_interval=CONF.openstack.nova_server_unrescue_poll_interval,
+            timeout=CONF.openstack.nova_server_unrescue_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.unrescue_server")
@@ -380,7 +381,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         servers = [self.server, self.server1]
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._delete_servers(servers, force=force)
-        check_interval = CONF.benchmark.nova_server_delete_poll_interval
+        check_interval = CONF.openstack.nova_server_delete_poll_interval
         expected = []
         for server in servers:
             expected.append(mock.call(
@@ -389,7 +390,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                 check_deletion=True,
                 update_resource=self.mock_get_from_manager.mock.return_value,
                 check_interval=check_interval,
-                timeout=CONF.benchmark.nova_server_delete_timeout))
+                timeout=CONF.openstack.nova_server_delete_timeout))
             if force:
                 server.force_delete.assert_called_once_with()
                 self.assertFalse(server.delete.called)
@@ -408,21 +409,21 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
     def test__force_delete_servers(self):
         self._test_delete_servers(force=True)
 
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
-    def test__delete_image(self, mock_wrap):
-        nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario._clients = mock.Mock()
+    @mock.patch("rally.plugins.openstack.scenarios.nova.utils.image_service")
+    def test__delete_image(self, mock_image_service):
+        glance = mock_image_service.Image.return_value
+        nova_scenario = utils.NovaScenario(context=self.context,
+                                           clients=mock.Mock())
         nova_scenario._delete_image(self.image)
-        self.clients("glance").images.delete.assert_called_once_with(
-            self.image.id)
+        glance.delete_image.assert_called_once_with(self.image.id)
         self.mock_wait_for_status.mock.assert_called_once_with(
             self.image,
             ready_statuses=["deleted", "pending_delete"],
             check_deletion=True,
-            update_resource=mock_wrap.return_value.get_image,
-            check_interval=CONF.benchmark.
+            update_resource=glance.get_image,
+            check_interval=CONF.openstack.
             nova_server_image_delete_poll_interval,
-            timeout=CONF.benchmark.nova_server_image_delete_timeout)
+            timeout=CONF.openstack.nova_server_image_delete_timeout)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.delete_image")
 
@@ -466,8 +467,8 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                 servers[i],
                 ready_statuses=["ACTIVE"],
                 update_resource=self.mock_get_from_manager.mock.return_value,
-                check_interval=CONF.benchmark.nova_server_boot_poll_interval,
-                timeout=CONF.benchmark.nova_server_boot_timeout)
+                check_interval=CONF.openstack.nova_server_boot_poll_interval,
+                timeout=CONF.openstack.nova_server_boot_timeout)
             for i in range(instances_amount)]
         self.mock_wait_for_status.mock.assert_has_calls(wait_for_status_calls)
 
@@ -494,6 +495,15 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.get_console_output_server")
 
+    def test__get_console_url(self):
+        nova_scenario = utils.NovaScenario(context=self.context)
+        nova_scenario._get_console_url_server(self.server, "foo")
+        self.clients(
+            "nova").servers.get_console_url.assert_called_once_with(
+            self.server, "foo")
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_console_url_server")
+
     def test__associate_floating_ip(self):
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._associate_floating_ip(self.server, self.floating_ip)
@@ -504,8 +514,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
 
     def test__associate_floating_ip_with_no_atomic_action(self):
         nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario._associate_floating_ip(self.server, self.floating_ip,
-                                             atomic_action=False)
+        nova_scenario._associate_floating_ip(self.server, self.floating_ip)
         self.server.add_floating_ip.assert_called_once_with(self.floating_ip,
                                                             fixed_address=None)
 
@@ -519,8 +528,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
 
     def test__dissociate_floating_ip_with_no_atomic_action(self):
         nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario._dissociate_floating_ip(self.server, self.floating_ip,
-                                              atomic_action=False)
+        nova_scenario._dissociate_floating_ip(self.server, self.floating_ip)
         self.server.remove_floating_ip.assert_called_once_with(
             self.floating_ip)
 
@@ -554,15 +562,6 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             nova_scenario.check_ip_address(floating_ip, must_exist=False)
             (fake_server))
 
-    def test__list_networks(self):
-        network_list = []
-        self.clients("nova").networks.list.return_value = network_list
-        nova_scenario = utils.NovaScenario(context=self.context)
-        return_network_list = nova_scenario._list_networks()
-        self.assertEqual(network_list, return_network_list)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.list_networks")
-
     def test__resize(self):
         nova_scenario = utils.NovaScenario(context=self.context)
         to_flavor = mock.Mock()
@@ -590,12 +589,21 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=[status],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.
+            check_interval=CONF.openstack.
             nova_server_resize_revert_poll_interval,
-            timeout=CONF.benchmark.nova_server_resize_revert_timeout)
+            timeout=CONF.openstack.nova_server_resize_revert_timeout)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.resize_revert")
 
+    @mock.patch("rally.plugins.openstack.services.storage.block.BlockStorage")
+    def test__update_volume_resource(self, mock_block_storage):
+        volume = fakes.FakeVolume(id=1)
+        cinder = mock_block_storage.return_value
+        cinder.get_volume = mock.MagicMock()
+        nova_scenario = utils.NovaScenario(context=self.context)
+        self.assertEqual(cinder.get_volume.return_value,
+                         nova_scenario._update_volume_resource(volume))
+
     def test__attach_volume(self):
         expect_attach = mock.MagicMock()
         device = None
@@ -609,13 +617,25 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.attach_volume")
 
+    def test__list_attachments(self):
+        expect_attachments = [mock.MagicMock()]
+        (self.clients("nova").volumes.get_server_volumes
+         .return_value) = expect_attachments
+        nova_scenario = utils.NovaScenario(context=self.context)
+        list_attachments = nova_scenario._list_attachments(self.server.id)
+        self.assertEqual(expect_attachments, list_attachments)
+        (self.clients("nova").volumes.get_server_volumes
+         .assert_called_once_with(self.server.id))
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.list_attachments")
+
     def test__detach_volume(self):
         attach = mock.MagicMock(id="attach_id")
         self.clients("nova").volumes.delete_server_volume.return_value = None
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._detach_volume(self.server, self.volume, attach)
         (self.clients("nova").volumes.delete_server_volume
-         .assert_called_once_with(self.server.id, attach.id))
+         .assert_called_once_with(self.server.id, self.volume.id))
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.detach_volume")
 
@@ -642,9 +662,9 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             self.server,
             ready_statuses=["ACTIVE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.
+            check_interval=CONF.openstack.
             nova_server_live_migrate_poll_interval,
-            timeout=CONF.benchmark.nova_server_live_migrate_timeout)
+            timeout=CONF.openstack.nova_server_live_migrate_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.live_migrate")
@@ -685,89 +705,16 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
             fake_server,
             ready_statuses=["VERIFY_RESIZE"],
             update_resource=self.mock_get_from_manager.mock.return_value,
-            check_interval=CONF.benchmark.nova_server_migrate_poll_interval,
-            timeout=CONF.benchmark.nova_server_migrate_timeout)
+            check_interval=CONF.openstack.nova_server_migrate_poll_interval,
+            timeout=CONF.openstack.nova_server_migrate_timeout)
         self.mock_get_from_manager.mock.assert_called_once_with()
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.migrate")
 
-        self.assertRaises(rally_exceptions.MigrateException,
+        self.assertRaises(rally_exceptions.RallyException,
                           nova_scenario._migrate,
                           fake_server, skip_host_check=False)
 
-    def test__create_security_groups(self):
-        nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario.generate_random_name = mock.MagicMock()
-
-        security_group_count = 5
-
-        sec_groups = nova_scenario._create_security_groups(
-            security_group_count)
-
-        self.assertEqual(security_group_count, len(sec_groups))
-        self.assertEqual(security_group_count,
-                         nova_scenario.generate_random_name.call_count)
-        self.assertEqual(
-            security_group_count,
-            self.clients("nova").security_groups.create.call_count)
-        self._test_atomic_action_timer(
-            nova_scenario.atomic_actions(),
-            "nova.create_%s_security_groups" % security_group_count)
-
-    def test__create_rules_for_security_group(self):
-        nova_scenario = utils.NovaScenario(context=self.context)
-
-        fake_secgroups = [fakes.FakeSecurityGroup(None, None, 1, "uuid1"),
-                          fakes.FakeSecurityGroup(None, None, 2, "uuid2")]
-        rules_per_security_group = 10
-
-        nova_scenario._create_rules_for_security_group(
-            fake_secgroups, rules_per_security_group)
-
-        self.assertEqual(
-            len(fake_secgroups) * rules_per_security_group,
-            self.clients("nova").security_group_rules.create.call_count)
-        self._test_atomic_action_timer(
-            nova_scenario.atomic_actions(),
-            "nova.create_%s_rules" %
-            (rules_per_security_group * len(fake_secgroups)))
-
-    def test__update_security_groups(self):
-        nova_scenario = utils.NovaScenario(context=self.context)
-        fake_secgroups = [fakes.FakeSecurityGroup(None, None, 1, "uuid1"),
-                          fakes.FakeSecurityGroup(None, None, 2, "uuid2")]
-        nova_scenario._update_security_groups(fake_secgroups)
-        self.assertEqual(
-            len(fake_secgroups),
-            self.clients("nova").security_groups.update.call_count)
-        self._test_atomic_action_timer(
-            nova_scenario.atomic_actions(),
-            "nova.update_%s_security_groups" % len(fake_secgroups))
-
-    def test__delete_security_groups(self):
-        nova_scenario = utils.NovaScenario(context=self.context)
-
-        fake_secgroups = [fakes.FakeSecurityGroup(None, None, 1, "uuid1"),
-                          fakes.FakeSecurityGroup(None, None, 2, "uuid2")]
-
-        nova_scenario._delete_security_groups(fake_secgroups)
-
-        self.assertSequenceEqual(
-            map(lambda x: mock.call(x.id), fake_secgroups),
-            self.clients("nova").security_groups.delete.call_args_list)
-        self._test_atomic_action_timer(
-            nova_scenario.atomic_actions(),
-            "nova.delete_%s_security_groups" % len(fake_secgroups))
-
-    def test__list_security_groups(self):
-        nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario._list_security_groups()
-
-        self.clients("nova").security_groups.list.assert_called_once_with()
-
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.list_security_groups")
-
     def test__add_server_secgroups(self):
         server = mock.Mock()
         fake_secgroups = [fakes.FakeSecurityGroup(None, None, 1, "uuid1")]
@@ -806,17 +753,43 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.create_keypair")
 
+    def test__get_server_group(self):
+        nova_scenario = utils.NovaScenario()
+        fakeid = 12345
+        result = nova_scenario._get_server_group(fakeid)
+        self.assertEqual(
+            self.clients("nova").server_groups.get.return_value,
+            result)
+        self.clients("nova").server_groups.get.assert_called_once_with(
+            fakeid)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.get_server_group")
+
     def test__create_server_group(self):
         nova_scenario = utils.NovaScenario()
+        nova_scenario.generate_random_name = mock.Mock(
+            return_value="random_name")
         result = nova_scenario._create_server_group(fakeargs="fakeargs")
         self.assertEqual(
             self.clients("nova").server_groups.create.return_value,
             result)
         self.clients("nova").server_groups.create.assert_called_once_with(
-            fakeargs="fakeargs")
+            name="random_name", fakeargs="fakeargs")
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.create_server_group")
 
+    def test__delete_server_group(self):
+        nova_scenario = utils.NovaScenario()
+        fakeid = 12345
+        result = nova_scenario._delete_server_group(fakeid)
+        self.assertEqual(
+            self.clients("nova").server_groups.delete.return_value,
+            result)
+        self.clients("nova").server_groups.delete.assert_called_once_with(
+            fakeid)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.delete_server_group")
+
     def test__list_server_groups(self):
         nova_scenario = utils.NovaScenario()
         result1 = nova_scenario._list_server_groups(all_projects=False)
@@ -848,41 +821,6 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.get_keypair")
 
-    def test__list_floating_ips_bulk(self):
-        floating_ips_bulk_list = ["foo_floating_ips_bulk"]
-        self.admin_clients("nova").floating_ips_bulk.list.return_value = (
-            floating_ips_bulk_list)
-        nova_scenario = utils.NovaScenario(context=self.context)
-        return_floating_ips_bulk_list = nova_scenario._list_floating_ips_bulk()
-        self.assertEqual(floating_ips_bulk_list, return_floating_ips_bulk_list)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.list_floating_ips_bulk")
-
-    @mock.patch(NOVA_UTILS + ".network_wrapper.generate_cidr")
-    def test__create_floating_ips_bulk(self, mock_generate_cidr):
-        fake_cidr = "10.2.0.0/24"
-        fake_pool = "test1"
-        fake_floating_ips_bulk = mock.MagicMock()
-        fake_floating_ips_bulk.ip_range = fake_cidr
-        fake_floating_ips_bulk.pool = fake_pool
-        self.admin_clients("nova").floating_ips_bulk.create.return_value = (
-            fake_floating_ips_bulk)
-        nova_scenario = utils.NovaScenario(context=self.context)
-        return_iprange = nova_scenario._create_floating_ips_bulk(fake_cidr)
-        mock_generate_cidr.assert_called_once_with(start_cidr=fake_cidr)
-        self.assertEqual(return_iprange, fake_floating_ips_bulk)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.create_floating_ips_bulk")
-
-    def test__delete_floating_ips_bulk(self):
-        fake_cidr = "10.2.0.0/24"
-        nova_scenario = utils.NovaScenario(context=self.context)
-        nova_scenario._delete_floating_ips_bulk(fake_cidr)
-        self.admin_clients(
-            "nova").floating_ips_bulk.delete.assert_called_once_with(fake_cidr)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.delete_floating_ips_bulk")
-
     def test__list_hypervisors(self):
         nova_scenario = utils.NovaScenario()
         result = nova_scenario._list_hypervisors(detailed=False)
@@ -936,15 +874,23 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.get_host")
 
-    def test__list_images(self):
+    def test__list_interfaces(self):
         nova_scenario = utils.NovaScenario()
-        result = nova_scenario._list_images(detailed=False, fakearg="fakearg")
-        self.assertEqual(self.clients("nova").images.list.return_value,
-                         result)
-        self.clients("nova").images.list.assert_called_once_with(
-            False, fakearg="fakearg")
+        result = nova_scenario._list_interfaces("server")
+        self.assertEqual(
+            self.clients("nova").servers.interface_list.return_value,
+            result)
+        self.clients("nova").servers.interface_list.assert_called_once_with(
+            "server")
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.list_images")
+                                       "nova.list_interfaces")
+
+    @mock.patch("rally.plugins.openstack.scenarios.nova.utils.image_service")
+    def test__list_images(self, mock_image_service):
+        result = utils.NovaScenario(clients=mock.Mock())._list_images()
+        glance = mock_image_service.Image.return_value
+        self.assertEqual(glance.list_images.return_value, result)
+        glance.list_images.assert_called_once_with()
 
     def test__lock_server(self):
         server = mock.Mock()
@@ -973,27 +919,6 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.delete_network")
 
-    @mock.patch(NOVA_UTILS + ".network_wrapper.generate_cidr")
-    def test__create_network(self, mock_generate_cidr):
-        nova_scenario = utils.NovaScenario()
-        nova_scenario.generate_random_name = mock.Mock(
-            return_value="rally_novanet_fake")
-
-        result = nova_scenario._create_network("fake_start_cidr",
-                                               fakearg="fakearg")
-
-        mock_generate_cidr.assert_called_once_with(
-            start_cidr="fake_start_cidr")
-
-        self.assertEqual(
-            self.admin_clients("nova").networks.create.return_value,
-            result)
-        self.admin_clients("nova").networks.create.assert_called_once_with(
-            label="rally_novanet_fake", cidr=mock_generate_cidr.return_value,
-            fakearg="fakearg")
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.create_network")
-
     def test__list_flavors(self):
         nova_scenario = utils.NovaScenario()
         result = nova_scenario._list_flavors(detailed=True, fakearg="fakearg")
@@ -1257,6 +1182,19 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.uptime_hypervisor")
 
+    def test__attach_interface(self):
+        fake_server = mock.Mock()
+        nova_scenario = utils.NovaScenario()
+
+        result = nova_scenario._attach_interface(fake_server, net_id="id")
+        self.assertEqual(
+            self.clients("nova").servers.interface_attach.return_value,
+            result)
+        self.clients("nova").servers.interface_attach.assert_called_once_with(
+            fake_server, None, "id", None)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.attach_interface")
+
     def test_aggregate_set_metadata(self):
         nova_scenario = utils.NovaScenario(context=self.context)
         fake_metadata = {"test_metadata": "true"}
