@@ -36,15 +36,13 @@ class SaharaScenarioTestCase(test.ScenarioTestCase):
     # get_from_manager() calls. As a result, the tests below do more
     # integrated/functional testing of wait_for() calls, and we can't
     # just mock out wait_for and friends the way we usually do.
-    patch_benchmark_utils = False
+    patch_task_utils = False
 
     def setUp(self):
         super(SaharaScenarioTestCase, self).setUp()
 
-        CONF.set_override("sahara_cluster_check_interval", 0, "benchmark",
-                          enforce_type=True)
-        CONF.set_override("sahara_job_check_interval", 0, "benchmark",
-                          enforce_type=True)
+        CONF.set_override("sahara_cluster_check_interval", 0, "openstack")
+        CONF.set_override("sahara_job_check_interval", 0, "openstack")
 
     def test_list_node_group_templates(self):
         ngts = []
