@@ -12,21 +12,33 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
 import ddt
+import fixtures
 import mock
-from oslotest import mockpatch
 
+from rally.plugins.openstack.credential import OpenStackCredential
 from rally.plugins.openstack import scenario as base_scenario
 from tests.unit import test
 
 
+CREDENTIAL_WITHOUT_HMAC = OpenStackCredential(
+    "auth_url",
+    "username",
+    "password")
+
+CREDENTIAL_WITH_HMAC = OpenStackCredential(
+    "auth_url",
+    "username",
+    "password",
+    profiler_hmac_key="test_profiler_hmac_key")
+
+
 @ddt.ddt
 class OpenStackScenarioTestCase(test.TestCase):
     def setUp(self):
         super(OpenStackScenarioTestCase, self).setUp()
-        self.osclients = mockpatch.Patch(
-            "rally.osclients.Clients")
+        self.osclients = fixtures.MockPatch(
+            "rally.plugins.openstack.osclients.Clients")
         self.useFixture(self.osclients)
         self.context = test.get_test_context()
         self.context.update({"foo": "bar"})
@@ -80,6 +92,34 @@ class OpenStackScenarioTestCase(test.TestCase):
 
         self.assertEqual("foobar", scenario._clients)
 
+    @ddt.data(([], 0),
+              ([("admin", CREDENTIAL_WITHOUT_HMAC)], 0),
+              ([("user", CREDENTIAL_WITHOUT_HMAC)], 0),
+              ([("admin", CREDENTIAL_WITH_HMAC)], 1),
+              ([("user", CREDENTIAL_WITH_HMAC)], 1),
+              ([("admin", CREDENTIAL_WITH_HMAC),
+                ("user", CREDENTIAL_WITH_HMAC)], 1),
+              ([("admin", CREDENTIAL_WITHOUT_HMAC),
+                ("user", CREDENTIAL_WITH_HMAC)], 1),
+              ([("admin", CREDENTIAL_WITH_HMAC),
+                ("user", CREDENTIAL_WITHOUT_HMAC)], 1),
+              ([("admin", CREDENTIAL_WITHOUT_HMAC),
+                ("user", CREDENTIAL_WITHOUT_HMAC)], 0))
+    @ddt.unpack
+    @mock.patch("rally.plugins.openstack.scenario.profiler.init")
+    @mock.patch("rally.plugins.openstack.scenario.profiler.get")
+    def test_profiler_init(self, users_credentials,
+                           expected_call_count,
+                           mock_profiler_get,
+                           mock_profiler_init):
+        for user, credential in users_credentials:
+            self.context.update({user: {"credential": credential}})
+        base_scenario.OpenStackScenario(self.context)
+        self.assertEqual(expected_call_count,
+                         mock_profiler_init.call_count)
+        self.assertEqual([mock.call()] * expected_call_count,
+                         mock_profiler_get.call_args_list)
+
     def test__choose_user_random(self):
         users = [{"credential": mock.Mock(), "tenant_id": "foo"}
                  for _ in range(5)]
@@ -127,30 +167,3 @@ class OpenStackScenarioTestCase(test.TestCase):
         self.assertEqual(self.context["tenants"][tenant_id],
                          self.context["tenant"])
         self.assertEqual(expected_tenant_id, tenant_id)
-
-    @mock.patch("rally.task.scenario.Scenario.validate")
-    def test_validate(self, mock_scenario_validate):
-        cred1 = mock.Mock()
-        cred2 = mock.Mock()
-        cred3 = mock.Mock()
-        self.osclients.mock.side_effect = [cred1, cred2, cred3]
-
-        base_scenario.OpenStackScenario.validate(
-            name="foo_name",
-            config="foo_config",
-            admin="foo_admin",
-            users=[{"credential": "foo_user1"},
-                   {"credential": "foo_user2"}],
-            deployment=None)
-
-        mock_scenario_validate.assert_called_once_with(
-            name="foo_name",
-            config="foo_config",
-            admin=cred1,
-            users=[cred2, cred3],
-            deployment=None)
-        self.osclients.mock.assert_has_calls([
-            mock.call("foo_admin"),
-            mock.call("foo_user1"),
-            mock.call("foo_user2"),
-        ])
