@@ -30,20 +30,17 @@ from tests.unit import test
 CONF = cfg.CONF
 
 
-CREDS = {
-    "admin": {
-        "username": "admin",
-        "tenant_name": "admin",
-        "password": "admin-12345",
-        "auth_url": "http://test:5000/v2.0/",
-        "permission": "admin",
-        "region_name": "test",
-        "https_insecure": False,
-        "https_cacert": "/path/to/cacert/file",
-        "user_domain_name": "admin",
-        "project_domain_name": "admin"
-    },
-    "uuid": "fake_deployment"
+CRED = {
+    "username": "admin",
+    "tenant_name": "admin",
+    "password": "admin-12345",
+    "auth_url": "http://test:5000/v2.0/",
+    "permission": "admin",
+    "region_name": "test",
+    "https_insecure": False,
+    "https_cacert": "/path/to/cacert/file",
+    "user_domain_name": "admin",
+    "project_domain_name": "admin"
 }
 
 PATH = "rally.plugins.openstack.verification.tempest.context"
@@ -55,11 +52,12 @@ class TempestContextTestCase(test.TestCase):
     def setUp(self):
         super(TempestContextTestCase, self).setUp()
 
-        mock.patch("rally.osclients.Clients").start()
         self.mock_isfile = mock.patch("os.path.isfile",
                                       return_value=True).start()
 
-        self.deployment = fakes.FakeDeployment(**CREDS)
+        self.cred = fakes.fake_credential(**CRED)
+        self.deployment = fakes.FakeDeployment(
+            uuid="fake_deployment", admin=self.cred)
         cfg = {"verifier": mock.Mock(deployment=self.deployment),
                "verification": {"uuid": "uuid"}}
         cfg["verifier"].manager.home_dir = "/p/a/t/h"
@@ -94,7 +92,7 @@ class TempestContextTestCase(test.TestCase):
         mock_get.return_value.iter_content.return_value = "data"
 
         self.context._download_image_from_source(img_path)
-        mock_get.assert_called_once_with(CONF.tempest.img_url, stream=True)
+        mock_get.assert_called_once_with(CONF.openstack.img_url, stream=True)
         mock_open.assert_called_once_with(img_path, "wb")
         mock_open().write.assert_has_calls([mock.call("d"),
                                             mock.call("a"),
@@ -138,15 +136,15 @@ class TempestContextTestCase(test.TestCase):
         glanceclient = self.context.clients.glance()
         novaclient = self.context.clients.nova()
 
-        self.assertEqual(glanceclient.images.create.call_count, 0)
-        self.assertEqual(novaclient.flavors.create.call_count, 0)
-        self.assertEqual(mock_neutron_wrapper_create_network.call_count, 0)
+        self.assertEqual(0, glanceclient.images.create.call_count)
+        self.assertEqual(0, novaclient.flavors.create.call_count)
+        self.assertEqual(0, mock_neutron_wrapper_create_network.call_count)
 
     def test__create_tempest_roles(self):
-        role1 = CONF.tempest.swift_operator_role
-        role2 = CONF.tempest.swift_reseller_admin_role
-        role3 = CONF.tempest.heat_stack_owner_role
-        role4 = CONF.tempest.heat_stack_user_role
+        role1 = CONF.openstack.swift_operator_role
+        role2 = CONF.openstack.swift_reseller_admin_role
+        role3 = CONF.openstack.heat_stack_owner_role
+        role4 = CONF.openstack.heat_stack_user_role
 
         client = self.context.clients.verified_keystone()
         client.roles.list.return_value = [fakes.FakeRole(name=role1),
@@ -155,15 +153,15 @@ class TempestContextTestCase(test.TestCase):
                                            fakes.FakeFlavor(name=role4)]
 
         self.context._create_tempest_roles()
-        self.assertEqual(client.roles.create.call_count, 2)
+        self.assertEqual(2, client.roles.create.call_count)
 
         created_roles = [role.name for role in self.context._created_roles]
         self.assertIn(role3, created_roles)
         self.assertIn(role4, created_roles)
 
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
-    def test__discover_image(self, mock_wrap):
-        client = mock_wrap.return_value
+    @mock.patch("rally.plugins.openstack.services.image.image.Image")
+    def test__discover_image(self, mock_image):
+        client = mock_image.return_value
         client.list_images.return_value = [fakes.FakeImage(name="Foo"),
                                            fakes.FakeImage(name="CirrOS")]
 
@@ -172,20 +170,20 @@ class TempestContextTestCase(test.TestCase):
 
     @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open(),
                 create=True)
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
+    @mock.patch("rally.plugins.openstack.services.image.image.Image")
     @mock.patch("os.path.isfile", return_value=False)
-    def test__download_image(self, mock_isfile, mock_wrap, mock_open):
+    def test__download_image(self, mock_isfile, mock_image, mock_open):
         img_1 = mock.MagicMock()
         img_1.name = "Foo"
         img_2 = mock.MagicMock()
         img_2.name = "CirrOS"
         glanceclient = self.context.clients.glance()
         glanceclient.images.data.return_value = "data"
-        mock_wrap.return_value.list_images.return_value = [img_1, img_2]
+        mock_image.return_value.list_images.return_value = [img_1, img_2]
 
         self.context._download_image()
         img_path = os.path.join(self.context.data_dir, self.context.image_name)
-        mock_wrap.return_value.list_images.assert_called_once_with(
+        mock_image.return_value.list_images.assert_called_once_with(
             status="active", visibility="public")
         glanceclient.images.data.assert_called_once_with(img_2.id)
         mock_open.assert_called_once_with(img_path, "wb")
@@ -203,14 +201,14 @@ class TempestContextTestCase(test.TestCase):
         self.context.conf.set("compute", "flavor_ref", "")
         self.context._configure_option("compute", "flavor_ref",
                                        helper_method=helper_method, flv_ram=64)
-        self.assertEqual(helper_method.call_count, 1)
+        self.assertEqual(1, helper_method.call_count)
 
         result = self.context.conf.get("compute", "flavor_ref")
         self.assertEqual("id1", result)
 
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
-    def test__discover_or_create_image_when_image_exists(self, mock_wrap):
-        client = mock_wrap.return_value
+    @mock.patch("rally.plugins.openstack.services.image.image.Image")
+    def test__discover_or_create_image_when_image_exists(self, mock_image):
+        client = mock_image.return_value
         client.list_images.return_value = [fakes.FakeImage(name="CirrOS")]
 
         image = self.context._discover_or_create_image()
@@ -218,20 +216,20 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual(0, client.create_image.call_count)
         self.assertEqual(0, len(self.context._created_images))
 
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
-    def test__discover_or_create_image(self, mock_wrap):
-        client = mock_wrap.return_value
+    @mock.patch("rally.plugins.openstack.services.image.image.Image")
+    def test__discover_or_create_image(self, mock_image):
+        client = mock_image.return_value
 
         image = self.context._discover_or_create_image()
-        self.assertEqual(image, client.create_image.return_value)
+        self.assertEqual(image, mock_image().create_image.return_value)
         self.assertEqual(self.context._created_images[0],
                          client.create_image.return_value)
-        client.create_image.assert_called_once_with(
-            container_format=CONF.tempest.img_container_format,
-            image_location=mock.ANY,
-            disk_format=CONF.tempest.img_disk_format,
-            name=mock.ANY,
-            visibility="public")
+        params = {"container_format": CONF.openstack.img_container_format,
+                  "image_location": mock.ANY,
+                  "disk_format": CONF.openstack.img_disk_format,
+                  "image_name": mock.ANY,
+                  "visibility": "public"}
+        client.create_image.assert_called_once_with(**params)
 
     def test__discover_or_create_flavor_when_flavor_exists(self):
         client = self.context.clients.nova()
@@ -244,6 +242,7 @@ class TempestContextTestCase(test.TestCase):
 
     def test__discover_or_create_flavor(self):
         client = self.context.clients.nova()
+        client.flavors.list.return_value = []
         client.flavors.create.side_effect = [fakes.FakeFlavor(id="id1")]
 
         flavor = self.context._discover_or_create_flavor(64)
@@ -260,6 +259,7 @@ class TempestContextTestCase(test.TestCase):
         client.create_network.side_effect = [{"network": fake_network}]
         client.create_router.side_effect = [{"router": {"id": "rid1"}}]
         client.create_subnet.side_effect = [{"subnet": {"id": "subid1"}}]
+        client.list_networks.return_value = {"networks": []}
 
         network = self.context._create_network_resources()
         self.assertEqual("nid1", network["id"])
@@ -274,18 +274,18 @@ class TempestContextTestCase(test.TestCase):
 
         self.context._cleanup_tempest_roles()
         client = self.context.clients.keystone()
-        self.assertEqual(client.roles.delete.call_count, 2)
+        self.assertEqual(2, client.roles.delete.call_count)
 
-    @mock.patch("rally.plugins.openstack.wrappers.glance.wrap")
-    def test__cleanup_images(self, mock_wrap):
+    @mock.patch("rally.plugins.openstack.services.image.image.Image")
+    def test__cleanup_images(self, mock_image):
         self.context._created_images = [fakes.FakeImage(id="id1"),
                                         fakes.FakeImage(id="id2")]
 
         self.context.conf.set("compute", "image_ref", "id1")
         self.context.conf.set("compute", "image_ref_alt", "id2")
 
-        wrapper = mock_wrap.return_value
-        wrapper.get_image.side_effect = [
+        image_service = mock_image.return_value
+        image_service.get_image.side_effect = [
             fakes.FakeImage(id="id1", status="DELETED"),
             fakes.FakeImage(id="id2"),
             fakes.FakeImage(id="id2", status="DELETED")]
@@ -309,7 +309,7 @@ class TempestContextTestCase(test.TestCase):
 
         self.context._cleanup_flavors()
         client = self.context.clients.nova()
-        self.assertEqual(client.flavors.delete.call_count, 3)
+        self.assertEqual(3, client.flavors.delete.call_count)
 
         self.assertEqual("", self.context.conf.get("compute", "flavor_ref"))
         self.assertEqual("", self.context.conf.get("compute",
@@ -325,7 +325,7 @@ class TempestContextTestCase(test.TestCase):
         self.context.conf.set("compute", "fixed_network_name", "net-12345")
 
         self.context._cleanup_network_resources()
-        self.assertEqual(mock_neutron_wrapper_delete_network.call_count, 1)
+        self.assertEqual(1, mock_neutron_wrapper_delete_network.call_count)
         self.assertEqual("", self.context.conf.get("compute",
                                                    "fixed_network_name"))
 
@@ -333,16 +333,14 @@ class TempestContextTestCase(test.TestCase):
     @mock.patch("%s.TempestContext._configure_option" % PATH)
     @mock.patch("%s.TempestContext._create_tempest_roles" % PATH)
     @mock.patch("rally.verification.utils.create_dir")
-    @mock.patch("%s.osclients.Clients" % PATH)
-    def test_setup(self, mock_clients, mock_create_dir,
+    def test_setup(self, mock_create_dir,
                    mock__create_tempest_roles, mock__configure_option,
                    mock_open):
-        self.deployment = fakes.FakeDeployment(**CREDS)
         verifier = mock.Mock(deployment=self.deployment)
         verifier.manager.home_dir = "/p/a/t/h"
 
         # case #1: no neutron and heat
-        mock_clients.return_value.services.return_value = {}
+        self.cred.clients.return_value.services.return_value = {}
 
         ctx = context.TempestContext({"verifier": verifier})
         ctx.conf = mock.Mock()
@@ -365,10 +363,10 @@ class TempestContextTestCase(test.TestCase):
                        helper_method=ctx._discover_or_create_image),
              mock.call("compute", "flavor_ref",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.tempest.flavor_ref_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_ram),
              mock.call("compute", "flavor_ref_alt",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.tempest.flavor_ref_alt_ram)],
+                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram)],
             mock__configure_option.call_args_list)
 
         mock_create_dir.reset_mock()
@@ -377,10 +375,12 @@ class TempestContextTestCase(test.TestCase):
         mock__configure_option.reset_mock()
 
         # case #2: neutron and heat are presented
-        mock_clients.return_value.services.return_value = {
+        self.cred.clients.return_value.services.return_value = {
             "network": "neutron", "orchestration": "heat"}
 
         ctx = context.TempestContext({"verifier": verifier})
+        neutron = ctx.clients.neutron()
+        neutron.list_networks.return_value = {"networks": ["fake_net"]}
         ctx.conf = mock.Mock()
         ctx.setup()
 
@@ -401,13 +401,13 @@ class TempestContextTestCase(test.TestCase):
                        helper_method=ctx._discover_or_create_image),
              mock.call("compute", "flavor_ref",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.tempest.flavor_ref_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_ram),
              mock.call("compute", "flavor_ref_alt",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.tempest.flavor_ref_alt_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram),
              mock.call("compute", "fixed_network_name",
                        helper_method=ctx._create_network_resources),
              mock.call("orchestration", "instance_type",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.tempest.heat_instance_type_ram)],
+                       flv_ram=config.CONF.openstack.heat_instance_type_ram)],
             mock__configure_option.call_args_list)
