@@ -36,7 +36,26 @@ class ChartTestCase(test.TestCase):
 
     @property
     def wload_info(self):
-        return {"iterations_count": 42, "atomic": {"a": {}, "b": {}, "c": {}}}
+        return {
+            "total_iteration_count": 42,
+            "statistics": {
+                "durations": {
+                    "total": {"name": "total",
+                              "duration": 6,
+                              "display_name": "total",
+                              "children": [],
+                              "count": 1},
+                    "atomics": [
+                        {"name": "a", "duration": 1, "display_name": "a",
+                         "children": [], "count": 1},
+                        {"name": "b", "duration": 2, "display_name": "b",
+                         "children": [], "count": 1},
+                        {"name": "c", "duration": 3, "display_name": "c",
+                         "children": [], "count": 1}
+                    ]
+                }
+            }
+        }
 
     def test___init__(self):
         self.assertRaises(TypeError, charts.Chart, self.wload_info)
@@ -72,15 +91,21 @@ class ChartTestCase(test.TestCase):
     def test__fix_atomic_actions(self):
         chart = self.Chart(self.wload_info)
         self.assertEqual(
-            {"atomic_actions": {"a": 5, "b": 6, "c": 0}},
-            chart._fix_atomic_actions({"atomic_actions": {"a": 5, "b": 6}}))
+            [("a", 5), ("b", 6), ("c", 0)],
+            chart._fix_atomic_actions({"a": {"duration": 5},
+                                       "b": {"duration": 6}}))
+
+    def test__get_atomic_names(self):
+        chart = self.Chart(self.wload_info)
+        self.assertEqual(["a", "b", "c"],
+                         chart._get_atomic_names())
 
 
 class MainStackedAreaChartTestCase(test.TestCase):
 
     def test_add_iteration_and_render(self):
-        chart = charts.MainStackedAreaChart({"iterations_count": 3,
-                                             "iterations_failed": 0}, 10)
+        chart = charts.MainStackedAreaChart({"total_iteration_count": 3,
+                                             "failed_iteration_count": 0}, 10)
         self.assertIsInstance(chart, charts.Chart)
         [chart.add_iteration(itr) for itr in (
             {"duration": 1.1, "idle_duration": 2.2, "error": []},
@@ -91,8 +116,8 @@ class MainStackedAreaChartTestCase(test.TestCase):
         self.assertEqual(expected, chart.render())
 
     def test_add_iteration_and_render_with_failed_iterations(self):
-        chart = charts.MainStackedAreaChart({"iterations_count": 3,
-                                             "iterations_failed": 2}, 10)
+        chart = charts.MainStackedAreaChart({"total_iteration_count": 3,
+                                             "failed_iteration_count": 2}, 10)
         self.assertIsInstance(chart, charts.Chart)
         [chart.add_iteration(itr) for itr in (
             {"duration": 1.1, "idle_duration": 2.2, "error": []},
@@ -108,33 +133,105 @@ class AtomicStackedAreaChartTestCase(test.TestCase):
 
     def test_add_iteration_and_render(self):
         iterations = (
-            {"atomic_actions": {"foo": 1.1}, "error": []},
-            {"atomic_actions": {"foo": 1.1, "bar": 1.2},
+            {"atomic_actions": [{"name": "foo",
+                                 "children": [],
+                                 "started_at": 0,
+                                 "finished_at": 1.1}],
+             "error": []},
+            {"atomic_actions": [{"name": "foo",
+                                 "children": [],
+                                 "started_at": 0,
+                                 "finished_at": 1.1},
+                                {"name": "bar",
+                                 "children": [],
+                                 "started_at": 0,
+                                 "finished_at": 1.2}
+                                ],
              "error": [], "duration": 40, "idle_duration": 2},
-            {"atomic_actions": {"bar": 1.2},
+            {"atomic_actions": [{"name": "bar",
+                                 "children": [],
+                                 "started_at": 0,
+                                 "finished_at": 1.2}],
              "error": [], "duration": 5.5, "idle_duration": 2.5})
         expected = [("bar", [[1, 0], [2, 1.2], [3, 1.2]]),
                     ("foo", [[1, 1.1], [2, 1.1], [3, 0]])]
         chart = charts.AtomicStackedAreaChart(
-            {"iterations_count": 3, "iterations_failed": 0,
-             "atomic": {"foo": {}, "bar": {}}}, 10)
+            {"total_iteration_count": 3,
+             "failed_iteration_count": 0,
+             "statistics": {
+                 "durations": {
+                     "total": {"name": "total",
+                               "duration": 3,
+                               "display_name": "total",
+                               "children": [],
+                               "count": 1},
+                     "atomics": [
+                         {"name": "foo", "duration": 1, "display_name": "foo",
+                          "children": [], "count": 1},
+                         {"name": "bar", "duration": 2, "display_name": "bar",
+                          "children": [], "count": 1}
+                     ]
+                 }
+             }}, 10)
         self.assertIsInstance(chart, charts.Chart)
         [chart.add_iteration(iteration) for iteration in iterations]
         self.assertEqual(expected, sorted(chart.render()))
 
     def test_add_iteration_and_render_with_failed_iterations(self):
         iterations = (
-            {"atomic_actions": {"foo": 1.1}, "error": []},
-            {"atomic_actions": {"foo": 1.1, "bar": 1.2},
-             "error": ["foo_err"], "duration": 40, "idle_duration": 2},
-            {"atomic_actions": {"bar": 1.2},
-             "error": ["foo_err"], "duration": 5.5, "idle_duration": 2.5})
+            {
+                "atomic_actions": [
+                    {"name": "foo",
+                     "started_at": 0,
+                     "finished_at": 1.1,
+                     "children": []}
+                ],
+                "error": []
+            },
+            {
+                "atomic_actions": [
+                    {"name": "foo",
+                     "started_at": 0,
+                     "finished_at": 1.1,
+                     "children": []},
+                    {"name": "bar",
+                     "started_at": 0,
+                     "finished_at": 1.2,
+                     "children": []}
+                ],
+                "error": ["foo_err"], "duration": 40, "idle_duration": 2},
+            {
+                "atomic_actions": [
+                    {"name": "bar",
+                     "started_at": 0,
+                     "finished_at": 1.2,
+                     "children": []}
+                ],
+                "error": ["foo_err"], "duration": 5.5, "idle_duration": 2.5})
         expected = [("bar", [[1, 0], [2, 1.2], [3, 1.2]]),
                     ("failed_duration", [[1, 0], [2, 39.7], [3, 6.8]]),
                     ("foo", [[1, 1.1], [2, 1.1], [3, 0]])]
         chart = charts.AtomicStackedAreaChart(
-            {"iterations_count": 3, "iterations_failed": 2,
-             "atomic": {"foo": {}, "bar": {}}}, 10)
+            {"total_iteration_count": 3, "failed_iteration_count": 2,
+             "statistics": {
+                 "durations": {
+                     "total": {"name": "total",
+                               "display_name": "total",
+                               "duration": 4,
+                               "count": 1,
+                               "children": []},
+                     "atomics": [
+                         {"name": "foo",
+                          "display_name": "foo",
+                          "duration": 2,
+                          "count": 1,
+                          "children": []},
+                         {"name": "bar",
+                          "display_name": "bar",
+                          "duration": 2,
+                          "count": 1,
+                          "children": []}
+                     ]}}}, 10)
         self.assertIsInstance(chart, charts.Chart)
         [chart.add_iteration(iteration) for iteration in iterations]
         self.assertEqual(expected, sorted(chart.render()))
@@ -147,23 +244,46 @@ class AvgChartTestCase(test.TestCase):
             return iteration["foo"].items()
 
     def test_add_iteration_and_render(self):
-        self.assertRaises(TypeError, charts.AvgChart, {"iterations_count": 3})
-        chart = self.AvgChart({"iterations_count": 3})
+        chart = self.AvgChart({"total_iteration_count": 3})
         self.assertIsInstance(chart, charts.AvgChart)
-        [chart.add_iteration({"foo": x}) for x in ({"a": 1.3, "b": 4.3},
-                                                   {"a": 2.4, "b": 5.4},
-                                                   {"a": 3.5, "b": 7.7})]
+        data = ({"a": 1.3, "b": 4.3},
+                {"a": 2.4, "b": 5.4},
+                {"a": 3.5, "b": 7.7})
+        for x in data:
+            chart.add_iteration({"foo": x})
         self.assertEqual([("a", 2.4), ("b", 5.8)], sorted(chart.render()))
 
 
 class AtomicAvgChartTestCase(test.TestCase):
 
     def test_add_iteration_and_render(self):
-        chart = charts.AtomicAvgChart({"iterations_count": 3,
-                                       "atomic": {"foo": {}, "bar": {}}})
+        chart = charts.AtomicAvgChart(
+            {"total_iteration_count": 3,
+             "statistics": {
+                 "durations": {
+                     "total": {"name": "total",
+                               "duration": 3,
+                               "display_name": "total",
+                               "children": [],
+                               "count": 1},
+                     "atomics": [
+                         {"name": "foo", "duration": 1, "display_name": "foo",
+                          "children": [], "count": 1},
+                         {"name": "bar", "duration": 2, "display_name": "bar",
+                          "children": [], "count": 1}
+                     ]
+                 }
+             }})
         self.assertIsInstance(chart, charts.AvgChart)
-        [chart.add_iteration({"atomic_actions": collections.OrderedDict(a)})
-         for a in ([("foo", 2), ("bar", 5)], [("foo", 4)], [("bar", 7)])]
+        for a in ([{"name": "foo", "started_at": 0, "finished_at": 2,
+                    "children": []},
+                   {"name": "bar", "started_at": 0, "finished_at": 5,
+                    "children": []}],
+                  [{"name": "foo", "started_at": 0, "finished_at": 4,
+                    "children": []}],
+                  [{"name": "bar", "started_at": 0, "finished_at": 7,
+                    "children": []}]):
+            chart.add_iteration({"atomic_actions": a})
         self.assertEqual([("bar", 4.0), ("foo", 2.0)], sorted(chart.render()))
 
 
@@ -171,8 +291,8 @@ class AtomicAvgChartTestCase(test.TestCase):
 class LoadProfileChartTestCase(test.TestCase):
 
     @ddt.data(
-        {"info": {"iterations_count": 9,
-                  "tstamp_start": 0.0,
+        {"info": {"total_iteration_count": 9,
+                  "data": [{"timestamp": 0.0}],
                   "load_duration": 8.0},
          "iterations": [(0.0, 0.5), (0.5, 0.5), (2.0, 4.0), (2.0, 2.0),
                         (4.0, 2.0), (6.0, 0.5), (6.5, 0.5), (7.5, 0.5),
@@ -182,8 +302,8 @@ class LoadProfileChartTestCase(test.TestCase):
                        [(0.0, 0), (1.25, 0.8), (2.5, 0.8), (3.75, 2),
                         (5.0, 2.0), (6.25, 1.8), (7.5, 0.6000000000000001),
                         (8.75, 1.4), (10.0, 0.2)])]},
-        {"info": {"iterations_count": 6,
-                  "tstamp_start": 0.0,
+        {"info": {"total_iteration_count": 6,
+                  "data": [{"timestamp": 0.0}],
                   "load_duration": 12.0},
          "iterations": [(0.0, 0.75), (0.75, 0.75), (1.5, 0.375), (3.0, 5.0),
                         (3.75, 4.25), (10.0, 1.0)],
@@ -193,11 +313,20 @@ class LoadProfileChartTestCase(test.TestCase):
                         (5.625, 2.0), (7.5, 2), (9.375, 0.5333333333333333),
                         (11.25, 0.5333333333333333), (13.125, 0),
                         (15.0, 0)])]},
-        {"info": {"iterations_count": 2,
-                  "tstamp_start": 0.0,
+        {"info": {"total_iteration_count": 2,
+                  "data": [{"timestamp": 0.0}],
                   "load_duration": 1.0},
          "iterations": [(0.0, 0.5), (0.5, 0.5)],
          "kwargs": {"scale": 4},
+         "expected": [("parallel iterations",
+                       [(0.0, 0), (0.375, 1.0), (0.75, 1.0),
+                        (1.125, 0.6666666666666666), (1.5, 0)])]},
+        {"info": {"total_iteration_count": 2,
+                  "data": [],
+                  "load_duration": 1.0,
+                  "start_time": 0.0},
+         "iterations": [(0.0, 0.5), (0.5, 0.5)],
+         "kwargs": {"scale": 4},
          "expected": [("parallel iterations",
                        [(0.0, 0), (0.375, 1.0), (0.75, 1.0),
                         (1.125, 0.6666666666666666), (1.5, 0)])]})
@@ -227,11 +356,10 @@ class HistogramChartTestCase(test.TestCase):
             return iteration["foo"].items()
 
     def test_add_iteration_and_render(self):
-        self.assertRaises(TypeError, charts.HistogramChart,
-                          {"iterations_count": 3})
-        chart = self.HistogramChart({"iterations_count": 3})
+        chart = self.HistogramChart({"total_iteration_count": 3})
         self.assertIsInstance(chart, charts.HistogramChart)
-        [chart.add_iteration({"foo": x}) for x in ({"bar": 1.2}, {"bar": 2.4},
+        [chart.add_iteration({"foo": x}) for x in ({"bar": 1.2},
+                                                   {"bar": 2.4},
                                                    {"bar": 4.2})]
         expected = {
             "data": [
@@ -270,7 +398,7 @@ class HistogramChartTestCase(test.TestCase):
     @ddt.unpack
     def test_views(self, base_size=None, min_value=None, max_value=None,
                    expected=None):
-        chart = self.HistogramChart({"iterations_count": base_size})
+        chart = self.HistogramChart({"total_iteration_count": base_size})
         self.assertEqual(expected, chart._init_views(min_value, max_value))
 
 
@@ -278,7 +406,7 @@ class MainHistogramChartTestCase(test.TestCase):
 
     def test_add_iteration_and_render(self):
         chart = charts.MainHistogramChart(
-            {"iterations_count": 3, "min_duration": 2, "max_duration": 7})
+            {"total_iteration_count": 3, "min_duration": 2, "max_duration": 7})
         self.assertIsInstance(chart, charts.HistogramChart)
         [chart.add_iteration(itr) for itr in (
             {"duration": 1.1, "idle_duration": 2.2, "error": None},
@@ -307,13 +435,44 @@ class AtomicHistogramChartTestCase(test.TestCase):
 
     def test_add_iteration_and_render(self):
         chart = charts.AtomicHistogramChart(
-            {"iterations_count": 3,
-             "atomic": collections.OrderedDict(
-                 [("foo", {"min_duration": 1.6, "max_duration": 2.8}),
-                  ("bar", {"min_duration": 3.1, "max_duration": 5.5})])})
+            {"total_iteration_count": 3, "statistics": {
+                "durations": {
+                    "total": {"name": "total",
+                              "duration": 6,
+                              "display_name": "total",
+                              "children": [],
+                              "count": 1},
+                    "atomics": [
+                        {
+                            "name": "foo",
+                            "duration": 1,
+                            "display_name": "foo",
+                            "children": [],
+                            "count": 1,
+                            "data": {"min": 1.6,
+                                     "max": 2.8}
+                        },
+                        {
+                            "name": "bar",
+                            "duration": 2,
+                            "display_name": "bar",
+                            "children": [],
+                            "count": 1,
+                            "data": {"min": 3.1,
+                                     "max": 5.5}}
+                    ]
+                }
+            }})
         self.assertIsInstance(chart, charts.HistogramChart)
         [chart.add_iteration({"atomic_actions": a})
-         for a in ({"foo": 1.6, "bar": 3.1}, {"foo": 2.8}, {"bar": 5.5})]
+         for a in ([{"name": "foo", "started_at": 0, "finished_at": 1.6,
+                     "children": []},
+                    {"name": "bar", "started_at": 0, "finished_at": 3.1,
+                     "children": []}],
+                   [{"name": "foo", "started_at": 0, "finished_at": 2.8,
+                     "children": []}],
+                   [{"name": "bar", "started_at": 0, "finished_at": 5.5,
+                     "children": []}])]
         expected = {
             "data": [
                 [{"disabled": 0, "key": "foo", "view": "Square Root Choice",
@@ -362,10 +521,11 @@ class TableTestCase(test.TestCase):
                     self._data[name][i][0].add(value)
 
     def test___init__(self):
-        self.assertRaises(TypeError, charts.Table, {"iterations_count": 42})
+        self.assertRaises(TypeError, charts.Table,
+                          {"total_iteration_count": 42})
 
     def test__round(self):
-        table = self.Table({"iterations_count": 4})
+        table = self.Table({"total_iteration_count": 4})
         streaming_ins = mock.Mock()
         streaming_ins.result.return_value = 42.424242
         self.assertRaises(TypeError, table._round, streaming_ins)
@@ -374,7 +534,7 @@ class TableTestCase(test.TestCase):
                          table._round(streaming_ins, True))
 
     def test__row_has_results(self):
-        table = self.Table({"iterations_count": 1})
+        table = self.Table({"total_iteration_count": 1})
         for st_cls in (charts.streaming.MinComputation,
                        charts.streaming.MaxComputation,
                        charts.streaming.MeanComputation):
@@ -384,7 +544,7 @@ class TableTestCase(test.TestCase):
             self.assertTrue(table._row_has_results([(st, None)]))
 
     def test__row_has_results_and_get_rows(self):
-        table = self.Table({"iterations_count": 3})
+        table = self.Table({"total_iteration_count": 3})
         self.assertFalse(table._row_has_results(table._data["foo"]))
         self.assertFalse(table._row_has_results(table._data["bar"]))
         self.assertEqual(
@@ -399,17 +559,26 @@ class TableTestCase(test.TestCase):
             table.get_rows())
 
     def test_render(self):
-        table = self.Table({"iterations_count": 42})
-        table.get_rows = lambda: "rows data"
+        table = self.Table({"total_iteration_count": 42})
+        table.get_rows = lambda: ["rows data"]
         self.assertEqual({"cols": ["Name", "Min", "Max", "Max rounded by 2"],
-                          "rows": "rows data"},
+                          "rows": ["rows data"],
+                          "styles": {0: "rich"}},
                          table.render())
 
 
 def generate_iteration(duration, error, *actions):
+    atomic_actions = [{"name": name,
+                       "started_at": 0,
+                       "finished_at": finished_at,
+                       "children": []}
+                      for name, finished_at in actions]
+    if error:
+        atomic_actions[-1]["failed"] = True
     return {
-        "atomic_actions": collections.OrderedDict(actions),
+        "atomic_actions": atomic_actions,
         "duration": duration,
+        "idle_duration": 0,
         "error": error
     }
 
@@ -419,43 +588,52 @@ class MainStatsTableTestCase(test.TestCase):
 
     @ddt.data(
         {
-            "info": {
-                "iterations_count": 1,
-                "atomic": collections.OrderedDict([("foo", {}), ("bar", {})])
-            },
+            "info": {"total_iteration_count": 1},
             "data": [
                 generate_iteration(10.0, False, ("foo", 1.0), ("bar", 2.0))
             ],
             "expected_rows": [
                 ["foo", 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, "100.0%", 1],
                 ["bar", 2.0, 2.0, 2.0, 2.0, 2.0, 2.0, "100.0%", 1],
-                ["total", 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "100.0%", 1]]
+                ["total", 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "100.0%", 1],
+                [" -> duration",
+                 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "100.0%", 1],
+                [" -> idle_duration",
+                 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "100.0%", 1]],
+            "expected_styles": {2: "rich", 3: "oblique", 4: "oblique"}
         },
         {
-            "info": {"iterations_count": 2, "atomic": {"foo": {}}},
+            "info": {"total_iteration_count": 2},
             "data": [
                 generate_iteration(10.0, True, ("foo", 1.0)),
                 generate_iteration(10.0, True, ("foo", 2.0))
             ],
             "expected_rows": [
-                ["foo", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", 2],
-                ["total", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", 2]]
+                ["foo", 1.0, 1.5, 1.9, 1.95, 2.0, 1.5, "0.0%", 2],
+                ["total", 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "0.0%", 2],
+                [" -> duration",
+                 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "0.0%", 2],
+                [" -> idle_duration",
+                 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "0.0%", 2]],
+            "expected_styles": {1: "rich", 2: "oblique", 3: "oblique"}
         },
         {
-            "info": {"iterations_count": 2, "atomic": {"foo": {}}},
+            "info": {"total_iteration_count": 2},
             "data": [
                 generate_iteration(10.0, False, ("foo", 1.0)),
                 generate_iteration(20.0, True, ("foo", 2.0))
             ],
             "expected_rows": [
-                ["foo", 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, "50.0%", 2],
-                ["total", 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, "50.0%", 2]]
+                ["foo", 1.0, 1.5, 1.9, 1.95, 2.0, 1.5, "50.0%", 2],
+                ["total", 10.0, 15.0, 19.0, 19.5, 20.0, 15.0, "50.0%", 2],
+                [" -> duration",
+                 10.0, 15.0, 19.0, 19.5, 20.0, 15.0, "50.0%", 2],
+                [" -> idle_duration",
+                 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "50.0%", 2]],
+            "expected_styles": {1: "rich", 2: "oblique", 3: "oblique"}
         },
         {
-            "info": {
-                "iterations_count": 4,
-                "atomic": collections.OrderedDict([("foo", {}), ("bar", {})])
-            },
+            "info": {"total_iteration_count": 4},
             "data": [
                 generate_iteration(10.0, False, ("foo", 1.0), ("bar", 4.0)),
                 generate_iteration(20.0, False, ("foo", 2.0), ("bar", 4.0)),
@@ -463,23 +641,24 @@ class MainStatsTableTestCase(test.TestCase):
                 generate_iteration(40.0, True, ("foo", 4.0), ("bar", 4.0))
             ],
             "expected_rows": [
-                ["foo", 1.0, 2.0, 2.8, 2.9, 3.0, 2.0, "75.0%", 4],
+                ["foo", 1.0, 2.5, 3.7, 3.85, 4.0, 2.5, "100.0%", 4],
                 ["bar", 4.0, 4.0, 4.0, 4.0, 4.0, 4.0, "75.0%", 4],
-                ["total", 10.0, 20.0, 28.0, 29.0, 30.0, 20.0, "75.0%", 4]]
+                ["total", 10.0, 25.0, 37.0, 38.5, 40.0, 25.0, "75.0%", 4],
+                [" -> duration",
+                 10.0, 25.0, 37.0, 38.5, 40.0, 25.0, "75.0%", 4],
+                [" -> idle_duration",
+                 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "75.0%", 4]],
+            "expected_styles": {2: "rich", 3: "oblique", 4: "oblique"}
         },
         {
-            "info": {
-                "iterations_count": 0,
-                "atomic": collections.OrderedDict()
-            },
+            "info": {"total_iteration_count": 0},
             "data": [],
             "expected_rows": [
-                ["total", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", 0]]
+                ["total", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", 0]],
+            "expected_styles": {0: "rich"}
         },
         {
-            "info": {"iterations_count": 4,
-                     "atomic": collections.OrderedDict([("foo", {}),
-                                                        ("bar", {})])},
+            "info": {"total_iteration_count": 4},
             "data": [
                 generate_iteration(1.6, True, ("foo", 1.2)),
                 generate_iteration(5.2, False, ("foo", 1.2)),
@@ -487,13 +666,94 @@ class MainStatsTableTestCase(test.TestCase):
                 generate_iteration(12.3, False, ("foo", 4.2), ("bar", 5.6))
             ],
             "expected_rows": [
-                ["foo", 1.2, 2.7, 3.9, 4.05, 4.2, 2.7, "66.7%", 3],
-                ["bar", 5.6, 5.6, 5.6, 5.6, 5.6, 5.6, "50.0%", 2],
-                ["total", 5.2, 8.75, 11.59, 11.945, 12.3, 8.75, "50.0%", 4]]
+                ["foo", 1.2, 1.2, 3.6, 3.9, 4.2, 2.2, "66.7%", 3],
+                ["bar", 4.8, 5.2, 5.52, 5.56, 5.6, 5.2, "50.0%", 2],
+                ["total", 1.6, 5.1, 10.17, 11.235, 12.3, 6.025, "50.0%", 4],
+                [" -> duration",
+                 1.6, 5.1, 10.17, 11.235, 12.3, 6.025, "50.0%", 4],
+                [" -> idle_duration",
+                 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "50.0%", 4]],
+            "expected_styles": {2: "rich", 3: "oblique", 4: "oblique"}
+        },
+        {
+            "info": {"total_iteration_count": 4},
+            "data": [
+                {
+                    "atomic_actions": [
+                        {"name": "foo",
+                         "started_at": 0,
+                         "finished_at": 3.3,
+                         "children": [
+                             {"name": "bar",
+                              "started_at": 0,
+                              "finished_at": 1.3,
+                              "children": []},
+                             {"name": "bar",
+                              "started_at": 0,
+                              "finished_at": 3.3,
+                              "children": []}]}
+                    ],
+                    "duration": 3.3,
+                    "idle_duration": 17,
+                    "error": False},
+                {
+                    "atomic_actions": [
+                        {"name": "foo",
+                         "started_at": 0,
+                         "finished_at": 7.3,
+                         "failed": True,
+                         "children": [
+                             {"name": "bar",
+                              "started_at": 0,
+                              "finished_at": 2.3,
+                              "children": []},
+                             {"name": "bar",
+                              "failed": True,
+                              "started_at": 0,
+                              "finished_at": 7.3,
+                              "children": []}]}
+                    ],
+                    "duration": 7.3,
+                    "idle_duration": 20,
+                    "error": True}
+            ],
+            "expected_rows": [
+                ["foo", 3.3, 5.3, 6.9, 7.1, 7.3, 5.3, "50.0%", 2],
+                [" -> bar (x2)", 4.6, 7.1, 9.1, 9.35, 9.6, 7.1, "50.0%", 2],
+                ["total", 20.3, 23.8, 26.6, 26.95, 27.3, 23.8, "50.0%", 2],
+                [" -> duration", 3.3, 5.3, 6.9, 7.1, 7.3, 5.3, "50.0%", 2],
+                [" -> idle_duration",
+                 17.0, 18.5, 19.7, 19.85, 20.0, 18.5, "50.0%", 2]],
+            "expected_styles": {1: "oblique", 2: "rich",
+                                3: "oblique", 4: "oblique"}
+        },
+        {
+            "info": {"total_iteration_count": 1},
+            "data": [
+                {
+                    "atomic_actions": [
+                        {"name": "foo",
+                         "started_at": 0,
+                         "finished_at": 7.3,
+                         "children": []}
+                    ],
+                    "duration": 7.3,
+                    "idle_duration": 20,
+                    "error": True}
+            ],
+            "expected_rows": [
+                ["foo", 7.3, 7.3, 7.3, 7.3, 7.3, 7.3, "100.0%", 1],
+                ["<no-name-action>", 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, "0.0%", 1],
+                ["total", 27.3, 27.3, 27.3, 27.3, 27.3, 27.3, "0.0%", 1],
+                [" -> duration", 7.3, 7.3, 7.3, 7.3, 7.3, 7.3, "0.0%", 1],
+                [" -> idle_duration", 20.0, 20.0, 20.0, 20.0, 20.0, 20.0,
+                 "0.0%", 1]],
+            "expected_styles": {2: "rich", 3: "oblique", 4: "oblique"}
         }
     )
     @ddt.unpack
-    def test_add_iteration_and_render(self, info, data, expected_rows):
+    def test_add_iteration_and_render(self, info, data, expected_rows,
+                                      expected_styles):
 
         table = charts.MainStatsTable(info)
         for el in data:
@@ -501,9 +761,83 @@ class MainStatsTableTestCase(test.TestCase):
         expected = {"cols": ["Action", "Min (sec)", "Median (sec)",
                              "90%ile (sec)", "95%ile (sec)", "Max (sec)",
                              "Avg (sec)", "Success", "Count"],
-                    "rows": expected_rows}
+                    "rows": expected_rows,
+                    "styles": expected_styles}
         self.assertEqual(expected, table.render())
 
+    def test_to_dict(self):
+        table = charts.MainStatsTable({"total_iteration_count": 4})
+        data = [generate_iteration(1.6, True, ("foo", 1.2)),
+                generate_iteration(5.2, False, ("foo", 1.2)),
+                generate_iteration(5.0, True, ("bar", 4.8)),
+                generate_iteration(12.3, False, ("foo", 4.2), ("bar", 5.6))]
+        for el in data:
+            table.add_iteration(el)
+
+        self.assertEqual({
+            "atomics": [{"children": [],
+                         "data": {"90%ile": 3.6,
+                                  "95%ile": 3.9,
+                                  "avg": 2.2,
+                                  "iteration_count": 3,
+                                  "max": 4.2,
+                                  "median": 1.2,
+                                  "min": 1.2,
+                                  "success": "66.7%"},
+                         "display_name": "foo",
+                         "count_per_iteration": 1,
+                         "name": "foo"},
+                        {"children": [],
+                         "data": {"90%ile": 5.52,
+                                  "95%ile": 5.56,
+                                  "avg": 5.2,
+                                  "iteration_count": 2,
+                                  "max": 5.6,
+                                  "median": 5.2,
+                                  "min": 4.8,
+                                  "success": "50.0%"},
+                         "display_name": "bar",
+                         "count_per_iteration": 1,
+                         "name": "bar"}],
+            "total": {"data": {"90%ile": 10.17,
+                               "95%ile": 11.235,
+                               "avg": 6.025,
+                               "iteration_count": 4,
+                               "max": 12.3,
+                               "median": 5.1,
+                               "min": 1.6,
+                               "success": "50.0%"},
+                      "display_name": "total",
+                      "count_per_iteration": 1,
+                      "name": "total",
+                      "children": [
+                          {"children": [],
+                           "count_per_iteration": 1,
+                           "data": {"90%ile": 10.17,
+                                    "95%ile": 11.235,
+                                    "avg": 6.025,
+                                    "iteration_count": 4,
+                                    "max": 12.3,
+                                    "median": 5.1,
+                                    "min": 1.6,
+                                    "success": "50.0%"},
+                           "display_name": "duration",
+                           "name": "duration"},
+                          {"children": [],
+                           "count_per_iteration": 1,
+                           "data": {"90%ile": 0.0,
+                                    "95%ile": 0.0,
+                                    "avg": 0.0,
+                                    "iteration_count": 4,
+                                    "max": 0.0,
+                                    "median": 0.0,
+                                    "min": 0.0,
+                                    "success": "50.0%"},
+                           "display_name": "idle_duration",
+                           "name": "idle_duration"}]
+                      }
+        }, table.to_dict())
+
 
 class OutputChartTestCase(test.TestCase):
 
@@ -512,23 +846,23 @@ class OutputChartTestCase(test.TestCase):
 
     def test___init__(self):
         self.assertRaises(TypeError,
-                          charts.OutputChart, {"iterations_count": 42})
+                          charts.OutputChart, {"total_iteration_count": 42})
 
-        chart = self.OutputChart({"iterations_count": 42})
+        chart = self.OutputChart({"total_iteration_count": 42})
         self.assertIsInstance(chart, charts.Chart)
 
     def test__map_iteration_values(self):
-        chart = self.OutputChart({"iterations_count": 42})
+        chart = self.OutputChart({"total_iteration_count": 42})
         self.assertEqual("foo data", chart._map_iteration_values("foo data"))
 
     def test_render(self):
-        chart = self.OutputChart({"iterations_count": 42})
+        chart = self.OutputChart({"total_iteration_count": 42})
         self.assertEqual(
             {"widget": "FooWidget", "data": [],
              "title": "", "description": "", "label": "", "axis_label": ""},
             chart.render())
 
-        chart = self.OutputChart({"iterations_count": 42},
+        chart = self.OutputChart({"total_iteration_count": 42},
                                  title="foo title", description="Test!",
                                  label="Foo label", axis_label="Axis label")
         self.assertEqual(
@@ -543,13 +877,14 @@ class OutputStackedAreaChartTestCase(test.TestCase):
     def test___init__(self):
         self.assertEqual("StackedArea", charts.OutputStackedAreaChart.widget)
 
-        chart = charts.OutputStackedAreaChart({"iterations_count": 42})
+        chart = charts.OutputStackedAreaChart({"total_iteration_count": 42})
         self.assertIsInstance(chart, charts.OutputChart)
 
     def test_render(self):
         # Explicit label
         chart = charts.OutputStackedAreaChart(
-            {"iterations_count": 2}, label="Label", axis_label="Axis label")
+            {"total_iteration_count": 2}, label="Label",
+            axis_label="Axis label")
         chart.add_iteration((("foo", 10), ("bar", 20)))
         # One iteration is transformed to Table
         self.assertEqual({"axis_label": "Axis label",
@@ -568,7 +903,7 @@ class OutputStackedAreaChartTestCase(test.TestCase):
                          chart.render())
 
         # No label
-        chart = charts.OutputStackedAreaChart({"iterations_count": 1})
+        chart = charts.OutputStackedAreaChart({"total_iteration_count": 1})
         chart.add_iteration((("foo", 10), ("bar", 20)))
         self.assertEqual({"axis_label": "",
                           "data": {"cols": ["Name", "Value"],
@@ -582,7 +917,7 @@ class OutputAvgChartTestCase(test.TestCase):
     def test___init__(self):
         self.assertEqual("Pie", charts.OutputAvgChart.widget)
 
-        chart = charts.OutputAvgChart({"iterations_count": 42})
+        chart = charts.OutputAvgChart({"total_iteration_count": 42})
         self.assertIsInstance(chart, charts.OutputChart)
         self.assertIsInstance(chart, charts.AvgChart)
 
@@ -599,8 +934,8 @@ class OutputTableTestCase(test.TestCase):
     def test___init__(self):
         self.assertEqual("Table", charts.OutputTable.widget)
         self.assertRaises(TypeError,
-                          charts.OutputTable, {"iterations_count": 42})
-        self.OutputTable({"iterations_count": 42})
+                          charts.OutputTable, {"total_iteration_count": 42})
+        self.OutputTable({"total_iteration_count": 42})
 
 
 @ddt.ddt
@@ -613,7 +948,7 @@ class OutputStatsTableTestCase(test.TestCase):
              "95%ile (sec)", "Max (sec)", "Avg (sec)", "Count"],
             charts.OutputStatsTable.columns)
 
-        table = charts.OutputStatsTable({"iterations_count": 42})
+        table = charts.OutputStatsTable({"total_iteration_count": 42})
         self.assertIsInstance(table, charts.Table)
 
     @ddt.data(
@@ -630,15 +965,18 @@ class OutputStatsTableTestCase(test.TestCase):
     @ddt.unpack
     def test_add_iteration_and_render(self, title, description, iterations,
                                       expected):
-        table = charts.OutputStatsTable({"iterations_count": len(iterations)},
-                                        title=title, description=description)
+        table = charts.OutputStatsTable(
+            {"total_iteration_count": len(iterations)},
+            title=title, description=description)
         for iteration in iterations:
             table.add_iteration(iteration)
+        styles = {1: "rich"} if iterations else {}
         self.assertEqual({"title": title,
                           "description": description,
                           "widget": "Table",
                           "data": {"cols": charts.OutputStatsTable.columns,
-                                   "rows": expected},
+                                   "rows": expected,
+                                   "styles": styles},
                           "label": "",
                           "axis_label": ""},
                          table.render())
@@ -662,7 +1000,8 @@ class ModuleTestCase(test.TestCase):
                             "must be 'dict'")},
               {"args": ["additive", {}],
                "expected": "additive output missing key 'title'"},
-              {"args": ["additive", {"title": "foo"}],
+              {"args": ["additive", collections.OrderedDict(
+                  [("title", "foo")])],
                "expected": "additive output missing key 'chart_plugin'"},
               {"args": ["additive", {"title": "a", "chart_plugin": "b"}],
                "expected": "additive output missing key 'data'"},
